<?php
/**
 * Copyright (c) WEB LOUPE. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

namespace WeloConsorsFinanz\Bootstrap;

use Shopware\Bundle\AttributeBundle\Service\CrudService;
use Shopware\Bundle\AttributeBundle\Service\TypeMapping;
use Shopware\Components\Model\ModelManager;

/**
 * Class Attributes
 *
 * @author    Cyprien Nkeneng <cyprien.nkeneng@webloupe.de>
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz\Bootstrap
 * @version   1
 */
class Attributes
{
    /**
     * @var CrudService
     */
    private $crudService;

    /**
     * @var ModelManager
     */
    private $modelManager;
    
    private $attributeTables = [
        's_user_attributes',
        's_order_attributes'
    ];
    
    /**
     * @param CrudService  $crudService
     * @param ModelManager $modelManager
     */
    public function __construct(CrudService $crudService, ModelManager $modelManager)
    {
        $this->crudService = $crudService;
        $this->modelManager = $modelManager;
    }
    
    public function install()
    {
        $this->crudService->update(
            's_user_attributes',
            'consors_finanz_userreference',
            TypeMapping::TYPE_STRING,
            [
                'displayInBackend' => true,
                'label' => 'User reference',
                'translatable' => true,
            ]
        );

        $this->crudService->update(
            's_order_attributes',
            'consors_finanz_is_order_booked',
            TypeMapping::TYPE_BOOLEAN,
            [
                'displayInBackend' => false,
            ]
        );

        $this->crudService->update(
            's_order_attributes',
            'consors_finanz_is_order_cancelled',
            TypeMapping::TYPE_BOOLEAN,
            [
                'displayInBackend' => false,
            ]
        );

        $this->crudService->update(
            's_order_attributes',
            'consors_finanz_order_credit_numbers',
            TypeMapping::TYPE_STRING,
            [
                'displayInBackend' => false,
            ]
        );

        $this->modelManager->generateAttributeModels($this->attributeTables);
    }
    
    public function uninstall()
    {
        if ($this->crudService->get('s_user_attributes', 'consors_finanz_userreference')) {
            $this->crudService->delete('s_user_attributes', 'consors_finanz_userreference');
        }
        if ($this->crudService->get('s_order_attributes', 'consors_finanz_is_order_booked')) {
            $this->crudService->delete('s_order_attributes', 'consors_finanz_is_order_booked');
        }
        if ($this->crudService->get('s_order_attributes', 'consors_finanz_is_order_cancelled')) {
            $this->crudService->delete('s_order_attributes', 'consors_finanz_is_order_cancelled');
        }
        if ($this->crudService->get('s_order_attributes', 'consors_finanz_order_credit_numbers')) {
            $this->crudService->delete('s_order_attributes', 'consors_finanz_order_credit_numbers');
        }
        $this->modelManager->generateAttributeModels($this->attributeTables);
    }
}
