<?php
/**
 * Copyright (c) Web Loupe. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

namespace WeloConsorsFinanz\Components\Consors\Request;

/**
 * Class ArtikelRequest
 *
 * @author    Cyprien Nkeneng <cyprien.nkeneng@webloupe.de>
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz\Components\Consors\Request
 * @version   1
 */
class ArtikelRequest
{
    /**
     * @var int $menge
     */
    protected $menge;

    /**
     * @var string $einheit
     */
    protected $einheit;

    /**
     * @var string $artikelnummer
     */
    protected $artikelnummer;

    /**
     * @var string $artikelbezeichnung
     */
    protected $artikelbezeichnung;

    /**
     * @var string $artikelzusatz
     */
    protected $artikelzusatz;

    /**
     * @var double $betrag
     */
    protected $betrag;

    /**
     * @var double $betrag_netto
     */
    protected $betrag_netto;

    /**
     * @var double $umsatzsteuersatz
     */
    protected $umsatzsteuersatz;

    /**
     * @var string $warengruppe
     */
    protected $warengruppe;

    /**
     * AddressRequest constructor.
     * @param $artikel
     */
    public function __construct(array $artikel)
    {
//        $this->dumb($artikel);
        $this->setParamData($artikel);
    }

    private function setParamData($artikel)
    {
        $this->setMenge($artikel['menge']);
        $this->setEinheit($artikel['einheit']);
        $this->setArtikelnummer($artikel['artikelnummer']);
        $this->setArtikelbezeichnung($artikel['artikelbezeichnung']);
        $this->setArtikelzusatz($artikel['artikelzusatz']);
        $this->setBetrag($artikel['betrag']);
        $this->setBetragNetto($artikel['betrag_netto']);
        $this->setUmsatzsteuersatz($artikel['umsatzsteuersatz']);
        $this->setWarengruppe($artikel['warengruppe']);
    }

    /**
     * @return string
     */
    public function getMenge()
    {
        return $this->menge;
    }

    /**
     * @param string $menge
     */
    public function setMenge(string $menge)
    {
        $this->menge = $menge;
    }

    /**
     * @return string
     */
    public function getEinheit()
    {
        return $this->einheit;
    }

    /**
     * @param string $einheit
     */
    public function setEinheit(string $einheit)
    {
        $this->einheit = $einheit;
    }

    /**
     * @return string
     */
    public function getArtikelnummer()
    {
        return $this->artikelnummer;
    }

    /**
     * @param string $artikelnummer
     */
    public function setArtikelnummer(string $artikelnummer)
    {
        $this->artikelnummer = $artikelnummer;
    }

    /**
     * @return string
     */
    public function getArtikelbezeichnung()
    {
        return $this->artikelbezeichnung;
    }

    /**
     * @param string $artikelbezeichnung
     */
    public function setArtikelbezeichnung(string $artikelbezeichnung)
    {
        $this->artikelbezeichnung = $artikelbezeichnung;
    }

    /**
     * @return string
     */
    public function getArtikelzusatz()
    {
        return $this->artikelzusatz;
    }

    /**
     * @param string $artikelzusatz
     */
    public function setArtikelzusatz(string $artikelzusatz)
    {
        $this->artikelzusatz = $artikelzusatz;
    }

    /**
     * @return float
     */
    public function getBetrag()
    {
        return $this->betrag;
    }

    /**
     * @param float $betrag
     */
    public function setBetrag(float $betrag)
    {
        $this->betrag = $betrag;
    }

    /**
     * @return double
     */
    public function getBetragNetto()
    {
        return $this->betrag_netto;
    }

    /**
     * @param float $betrag_netto
     */
    public function setBetragNetto(float $betrag_netto)
    {
        $this->betrag_netto = $betrag_netto;
    }

    /**
     * @return float
     */
    public function getUmsatzsteuersatz()
    {
        return $this->umsatzsteuersatz;
    }

    /**
     * @param float $umsatzsteuersatz
     */
    public function setUmsatzsteuersatz(float $umsatzsteuersatz)
    {
        $this->umsatzsteuersatz = $umsatzsteuersatz;
    }

    /**
     * @return string
     */
    public function getWarengruppe()
    {
        return $this->warengruppe;
    }

    /**
     * @param string $warengruppe
     */
    public function setWarengruppe(string $warengruppe)
    {
        $this->warengruppe = $warengruppe;
    }

    function dumb($data){
        highlight_string("<?php\n " . var_export($data, true) . "?>");
        echo '<script>document.getElementsByTagName("code")[0].getElementsByTagName("span")[1].remove() ;document.getElementsByTagName("code")[0].getElementsByTagName("span")[document.getElementsByTagName("code")[0].getElementsByTagName("span").length - 1].remove() ; </script>';
        die();
    }
}