<?php
/**
 * Copyright (c) Web Loupe. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

namespace WeloConsorsFinanz\Components\Consors\Request;

/**
 * Class BelegPositionRequest
 *
 * @author    Cyprien Nkeneng <cyprien.nkeneng@webloupe.de>
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz\Components\Consors\Request
 * @version   1
 */
class BelegPositionRequest
{
    /**
     * @var string $kundennummer
     */
    protected $kundennummer;

    /**
     * @var string $belegpositionsnummer
     */
    protected $belegpositionsnummer;

    /**
     * @var double $betrag
     */
    protected $betrag;

    /**
     * @var double $betrag_netto
     */
    protected $betrag_netto;

    /**
     * @var double $umsatzsteuersatz
     */
    protected $umsatzsteuersatz;

    /**
     * @var string $waehrung
     */
    protected $waehrung;

    /** @var ArtikelRequest[] $artikel */
    protected $artikel;

    /**
     * HeaderRequest constructor.
     * @param $position
     */
    public function __construct($position)
    {
        $this->setKundennummer($position['kundennummer']);
        $this->setBelegpositionsnummer($position['belegpositionsnummer']);
        $this->setBetrag($position['betrag']);
        $this->setBetragnetto($position['betrag_netto']);
        $this->setUmsatzsteuersatz($position['umsatzsteuersatz']);
        $this->setWaehrung($position['waehrung']);

        $this->manageArticles($position['artikel']);
    }

    private function manageArticles($articles)
    {
        $array = [];
        foreach ($articles as $article) {
//            $this->dumb($article);
            $array[] = new ArtikelRequest($article);
        }


        $this->setArtikel($array);
    }

    /**
     * @return string
     */
    public function getKundennummer()
    {
        return $this->kundennummer;
    }

    /**
     * @param string $kundennummer
     */
    public function setKundennummer(string $kundennummer)
    {
        $this->kundennummer = $kundennummer;
    }

    /**
     * @return float
     */
    public function getBetrag()
    {
        return $this->betrag;
    }

    /**
     * @param float $betrag
     */
    public function setBetrag(float $betrag)
    {
        $this->betrag = $betrag;
    }

    /**
     * @return double
     */
    public function getBetragnetto()
    {
        return $this->betrag_netto;
    }

    /**
     * @param float $betrag_netto
     */
    public function setBetragnetto(float $betrag_netto)
    {
        $this->betrag_netto = $betrag_netto;
    }

    /**
     * @return string
     */
    public function getBelegpositionsnummer()
    {
        return $this->belegpositionsnummer;
    }

    /**
     * @param string $belegpositionsnummer
     */
    public function setBelegpositionsnummer(string $belegpositionsnummer)
    {
        $this->belegpositionsnummer = $belegpositionsnummer;
    }

    /**
     * @return float
     */
    public function getUmsatzsteuersatz()
    {
        return $this->umsatzsteuersatz;
    }

    /**
     * @param float $umsatzsteuersatz
     */
    public function setUmsatzsteuersatz(float $umsatzsteuersatz)
    {
        $this->umsatzsteuersatz = $umsatzsteuersatz;
    }

    /**
     * @param string $waehrung
     */
    public function setWaehrung(string $waehrung)
    {
        $this->waehrung = $waehrung;
    }

    /**
     * @return string
     */
    public function getWaehrung()
    {
        return $this->waehrung;
    }

    /**
     * @return ArtikelRequest[]
     */
    public function getArtikel(): array
    {
        return $this->artikel;
    }

    /**
     * @param ArtikelRequest[] $artikel
     */
    public function setArtikel(array $artikel)
    {
        $this->artikel = $artikel;
    }

    function dumb($data){
        highlight_string("<?php\n " . var_export($data, true) . "?>");
        echo '<script>document.getElementsByTagName("code")[0].getElementsByTagName("span")[1].remove() ;document.getElementsByTagName("code")[0].getElementsByTagName("span")[document.getElementsByTagName("code")[0].getElementsByTagName("span").length - 1].remove() ; </script>';
        die();
    }
}