<?php
/**
 * Copyright (c) Web Loupe. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

namespace WeloConsorsFinanz\Components\Consors\Request;

/**
 * Class BoniCheck2Request
 *
 * @author    Cyprien Nkeneng <cyprien.nkeneng@webloupe.de>
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz\Components\Consors\Request
 * @version   1
 */
class BoniCheck2Request extends AbstractRequest
{
    /**
     * @var string $kontotyp
     */
    private $kontotyp;

    /**
     * @var string $kontonummer
     */
    private $kontonummer;

    /**
     * @var PersonRequest $person
     */
    private $person;

    /**
     * @var PersonRequest $lieferperson
     */
    private $lieferperson;

    /**
     * @var MainAddressRequest $lieferanschrift
     */
    private $lieferanschrift;

    /**
     * BoniCheck2Request constructor.
     * @param $params
     */
    public function __construct($params)
    {
        parent::__construct($params);

        $this->setParamData($params);
        $this->setKontotyp($params['kontotype']);
    }

    /**
     * @return string
     */
    public function getKontotyp()
    {
        return $this->kontotyp;
    }

    /**
     * @param string $kontotyp
     */
    public function setKontotyp(string $kontotyp)
    {
        $this->kontotyp = $kontotyp;
    }

    /**
     * @return mixed
     */
    public function getKontonummer()
    {
        return $this->kontonummer;
    }

    /**
     * @param $kontonummer
     */
    public function setKontonummer(string $kontonummer)
    {
        $this->kontonummer = $kontonummer;
    }

    /**
     * @return PersonRequest
     */
    public function getPerson(): PersonRequest
    {
        return $this->person;
    }

    /**
     * @param PersonRequest $person
     */
    public function setPerson(PersonRequest $person)
    {
        $this->person = $person;
    }

    private function setParamData($params)
    {
        $this->setKontonummer($params['kontonummer']);
        $this->setPerson(new PersonRequest($params['person']));
        $this->setLieferperson(new PersonRequest($params['lieferperson']));
        $this->setLieferanschrift(new MainAddressRequest($params['lieferanschrift']));
    }

    /**
     * @return PersonRequest
     */
    public function getLieferperson(): PersonRequest
    {
        return $this->lieferperson;
    }

    /**
     * @param PersonRequest $lieferperson
     */
    public function setLieferperson(PersonRequest $lieferperson)
    {
        $this->lieferperson = $lieferperson;
    }

    /**
     * @return MainAddressRequest
     */
    public function getLieferanschrift(): MainAddressRequest
    {
        return $this->lieferanschrift;
    }

    /**
     * @param MainAddressRequest $lieferanschrift
     */
    public function setLieferanschrift(MainAddressRequest $lieferanschrift): void
    {
        $this->lieferanschrift = $lieferanschrift;
    }

    function dumb($data) {
        highlight_string("<?php\n " . var_export($data, true) . "?>");
        echo '<script>document.getElementsByTagName("code")[0].getElementsByTagName("span")[1].remove() ;document.getElementsByTagName("code")[0].getElementsByTagName("span")[document.getElementsByTagName("code")[0].getElementsByTagName("span").length - 1].remove() ; </script>';
        die();
    }
}
