<?php
/**
 * Copyright (c) Web Loupe. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

namespace WeloConsorsFinanz\Components\Consors\Request;

/**
 * Class PersonRequest
 *
 * @author    Cyprien Nkeneng <cyprien.nkeneng@webloupe.de>
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz\Components\Consors\Request
 * @version   1
 */
class PersonRequest
{
    /**
     * @var string $vorname
     */
    protected $vorname;

    /**
     * @var string $name
     */
    protected $name;

    /**
     * @var string $anrede
     */
    protected $anrede;

    /**
     * @var string $geburtsdatum
     */
    protected $geburtsdatum;

    /**
     * @var MainAddressRequest $hauptanschrift
     */
    protected $hauptanschrift;

    /** @var BankVerbindungRequest $bankverbindungen */
    protected $bankverbindungen;

    /**
     * @var ContactRequest[] $kontakte
     */
    protected $kontakte;

    /**
     * @var $rechtsform
     */
    protected $rechtsform;

    /**
     * @var $handelsregisternummer
     */
    protected $handelsregisternummer;

    /** @var $amtsgericht */
    protected $amtsgericht;

    /**
     * PersonRequest constructor.
     * @param $person
     */
    public function __construct($person)
    {
//        $this->dumb($person);
        $this->setParamData($person);
    }

    private function setParamData($person)
    {
        $this->setVorname($person['vorname']);
        $this->setName($person['name']);
        $this->setAnrede($person['salutation']);
        $this->setGeburtsdatum($person['geburtsdatum']);
        $this->setHauptanschrift(new MainAddressRequest($person['hauptanschrift']));
        $this->setRechtsform($person['rechtsform']);
        $this->setHandelsregisternummer($person['handelsregisternummer']);
        $this->setAmtsgericht($person['amtsgericht']);

        $kontakte = [];
        foreach ($person['kontakte'] as $contact) {
            $kontakte[] = new ContactRequest($contact);
        }

        $this->setKontakte($kontakte);

        if (isset($person['bankverbindungen'])) {
            $this->setBankverbindungen(new BankVerbindungRequest($person['bankverbindungen']));
        }
    }

    /**
     * @return string
     */
    public function getVorname()
    {
        return $this->vorname;
    }

    /**
     * @param string $vorname
     */
    public function setVorname(string $vorname)
    {
        $this->vorname = $vorname;
    }

    /**
     * @return string
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * @param string $name
     */
    public function setName(string $name)
    {
        $this->name = $name;
    }

    /**
     * @return string
     */
    public function getAnrede()
    {
        return $this->anrede;
    }

    /**
     * @param string $anrede
     */
    public function setAnrede(string $anrede)
    {
        $this->anrede = $anrede;
    }

    /**
     * @return string
     */
    public function getGeburtsdatum()
    {
        return $this->geburtsdatum;
    }

    /**
     * @param string $geburtsdatum
     */
    public function setGeburtsdatum(string $geburtsdatum)
    {
        $this->geburtsdatum = $geburtsdatum;
    }

    /**
     * @return MainAddressRequest
     */
    public function getHauptanschrift(): MainAddressRequest
    {
        return $this->hauptanschrift;
    }

    /**
     * @param MainAddressRequest $hauptanschrift
     */
    public function setHauptanschrift(MainAddressRequest $hauptanschrift)
    {
        $this->hauptanschrift = $hauptanschrift;
    }

    /**
     * @return BankVerbindungRequest
     */
    public function getBankverbindungen(): BankVerbindungRequest
    {
        return $this->bankverbindungen;
    }

    /**
     * @param BankVerbindungRequest $bankverbindungen
     */
    public function setBankverbindungen(BankVerbindungRequest $bankverbindungen)
    {
        $this->bankverbindungen = $bankverbindungen;
    }

    /**
     * @return mixed
     */
    public function getRechtsform()
    {
        return $this->rechtsform;
    }

    /**
     * @param mixed $rechtsform
     */
    public function setRechtsform($rechtsform)
    {
        $this->rechtsform = $rechtsform;
    }

    /**
     * @return mixed
     */
    public function getHandelsregisternummer()
    {
        return $this->handelsregisternummer;
    }

    /**
     * @param mixed $handelsregisternummer
     */
    public function setHandelsregisternummer($handelsregisternummer): void
    {
        $this->handelsregisternummer = $handelsregisternummer;
    }

    /**
     * @return mixed
     */
    public function getAmtsgericht()
    {
        return $this->amtsgericht;
    }

    /**
     * @param mixed $amtsgericht
     */
    public function setAmtsgericht($amtsgericht)
    {
        $this->amtsgericht = $amtsgericht;
    }

    /**
     * @return array
     */
    public function getKontakte(): array
    {
        return $this->kontakte;
    }

    /**
     * @param array $kontakte
     * @return PersonRequest
     */
    public function setKontakte(Array $kontakte)
    {
        $this->kontakte = $kontakte;
        return $this;
    }

    function dumb($data){
        highlight_string("<?php\n " . var_export($data, true) . "?>");
        echo '<script>document.getElementsByTagName("code")[0].getElementsByTagName("span")[1].remove() ;document.getElementsByTagName("code")[0].getElementsByTagName("span")[document.getElementsByTagName("code")[0].getElementsByTagName("span").length - 1].remove() ; </script>';
        die();
    }
}