<?php
/**
 * Copyright (c) Web Loupe. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

namespace WeloConsorsFinanz\Components\Consors\Services;

use Shopware\Components\DependencyInjection\Container as DIContainer;
use Shopware\Components\Model\ModelManager;
use WeloConsorsFinanz\Components\Configuration;
use WeloConsorsFinanz\Components\Consors\Api\ConsorsSoapClientFault;
use WeloConsorsFinanz\Components\Consors\Request\BoniCheck2Request;
use WeloConsorsFinanz\Components\Consors\Response\BoniCheck2Response;
use WeloConsorsFinanz\Components\DependencyProvider;

/**
 * Class BoniCheckService
 *
 * @author    Cyprien Nkeneng <cyprien.nkeneng@webloupe.de> - www.webloupe.de
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz\Components\Consors\Services
 * @link      https://www.webloupe.de
 * @version   1
 */
class BoniCheckService extends AbstractService
{
    const ACCOUNT_TYPE = 'ESHOPKONTONUM';

    /**
     * @param        $sOrderVariables
     * @param string $anfrageart
     * @return BoniCheck2Response
     * @throws ConsorsSoapClientFault
     */
    public function checkBoni($sOrderVariables, string $anfrageart)
    {
//        $this->dumb($this->orderData);
        if (empty($this->orderData)) {
            $this->orderData = $sOrderVariables;
            $this->orderData['sBasket'] = $this->getBasket();
        }

        $request = $this->getRequest($anfrageart);
//        $this->dumb($request);

        /** @var BoniCheck2Response $response */
        $response = $this->consorsApi->boniCheck2($request);
        return $response;
    }

    /**
     * @param $anfrageart
     * @return BoniCheck2Request
     */
    private function getRequest($anfrageart)
    {
        $params = array_merge(
            $this->getDefaultParams($anfrageart),
            $this->getBoniParams()
        );
        return new BoniCheck2Request($params);
    }

    /**
     * @return array
     */
    private function getBoniParams()
    {
        $userData = $this->orderData['sUserData'];
        $user = $userData['additional']['user'];
        $billingAddress = $userData['billingaddress'];
        $shippingaddress = $userData['shippingaddress'];

        return [
            'kontotype' => self::ACCOUNT_TYPE,
            'kontonummer' => $user['customernumber'],
            'person' => $this->getPerson($user, $billingAddress),
            'lieferperson' => $this->getPerson($user, $shippingaddress, true),
            'lieferanschrift' => [
                'adresse' => $this->getAddress($shippingaddress),
                'zusatz' => $shippingaddress['additionalAddressLine1']
            ],
        ];
    }

    private function getPerson($user, $address, $liefer = false)
    {
//        $this->dumb($user);
        $person = [
                'salutation' => $this->translateSalutation($address['salutation']),
                'vorname' => ($liefer === true) ? $address['firstname'] : $user['firstname'],
                'name' => ($liefer === true) ? $address['lastname'] : $user['lastname'],
                'geburtsdatum' => $user['birthday'],
                'hauptanschrift' => [
                    'adresse' => $this->getAddress($address),
                    'zusatz' => $address['additionalAddressLine1']
                ],
                'kontakte' => [
                    [
                        'typ' => 'mobil',
                        'kontakt' => $address['phone']
                    ],
                    [
                        'typ' => 'email',
                        'kontakt' => $user['email']
                    ],
                ],
                'rechtsform' => '',
                'handelsregisternummer' => '',
                'amtsgericht' => '',
        ];

        $bankData = $this->getUserBankData($user['id']);
        if (!empty($bankData)) {
            $person = array_merge(
                $person,
                ['bankverbindungen' => $bankData]
            );
        }
        return $person;
    }

    function dumb($data) {
        highlight_string("<?php\n " . var_export($data, true) . "?>");
        echo '<script>document.getElementsByTagName("code")[0].getElementsByTagName("span")[1].remove() ;document.getElementsByTagName("code")[0].getElementsByTagName("span")[document.getElementsByTagName("code")[0].getElementsByTagName("span").length - 1].remove() ; </script>';
        die();
    }
}