<?php
/**
 * Copyright (c) Web Loupe. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

namespace WeloConsorsFinanz\Components\Consors\Services;

use sOrder;
use WeloConsorsFinanz\Components\Consors\Api\ConsorsSoapClientFault;
use WeloConsorsFinanz\Components\Consors\Request\Order2Request;
use WeloConsorsFinanz\Components\Consors\Response\Order2Response;

/**
 * Class OrderService
 *
 * @author    Cyprien Nkeneng <cyprien.nkeneng@webloupe.de>
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz\Components\Consors\Services
 * @version   1
 */
class OrderService extends AbstractService
{
    /**
     * @param $anfrageart
     * @param $ordernumber
     * @return mixed
     * @throws ConsorsSoapClientFault
     */
    public function order($anfrageart, $ordernumber)
    {
        $request = $this->getParams($anfrageart, $ordernumber);

//        $this->dumb($request);
        /** @var Order2Response $response */
        $response = $this->consorsApi->order2($request);
        return $response;
    }

    /**
     * @param $anfrageart
     * @param $ordernumber
     * @return Order2Request
     */
    private function getParams($anfrageart, $ordernumber)
    {
        $params = array_merge(
            $this->getDefaultParams($anfrageart),
            $this->getOrderParams($ordernumber)
        );

        return new Order2Request($params);
    }

    /**
     * @param $ordernumber
     * @return \string[][]
     */
    private function getOrderParams($ordernumber)
    {
        return [
            'referenzen' => [
                'referenztyp' => 'bestellnummer',
                'referenzwert' => $ordernumber,
            ]
        ];
    }

    public function reserveOrdernumber()
    {
        $session = Shopware()->Session();
        if (empty($session['consorsPaymentReference'])){
            $order = new sOrder();
            $session['consorsPaymentReference'] = $order->sGetOrderNumber();
        }
        return $session['consorsPaymentReference'];
    }

    /**
     * @param string $orderNumber
     */
    public function setClearedDate($orderNumber)
    {
        $builder = $this->modelManager->getConnection()->createQueryBuilder();
        $builder->update('s_order', 'o')
            ->set('o.cleareddate', 'NOW()')
            ->where('o.ordernumber = :orderNumber')
            ->setParameter(':orderNumber', $orderNumber)
            ->execute();
    }
}