<?php
/**
 * Copyright (c) Web Loupe. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

namespace WeloConsorsFinanz\Components\Consors\Services;

use WeloConsorsFinanz\Components\Consors\Api\ConsorsSoapClientFault;
use WeloConsorsFinanz\Components\Consors\Request\OrderStornoRequest;
use WeloConsorsFinanz\Components\Consors\Response\OrderStornoResponse;

/**
 * Class OrderStornoService
 *
 * @author    Cyprien Nkeneng <cyprien.nkeneng@webloupe.de> - www.webloupe.de
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz\Components\Consors\Services
 * @link      https://www.webloupe.de
 * @version   1
 */
class OrderStornoService extends AbstractService
{
    /**
     * @param $ordernumber
     * @param $anfrageart
     * @return OrderStornoResponse
     * @throws ConsorsSoapClientFault
     */
    public function cancel($ordernumber, $anfrageart)
    {
//        die('test '.$ordernumber);
        $request = $this->getParams($ordernumber, $anfrageart);

        /** @var OrderStornoResponse $response */
        $response = $this->consorsApi->cancelOrder($request);
        return $response;
    }

    /**
     * @param $ordernumber
     * @param $anfrageart
     * @return OrderStornoRequest
     */
    private function getParams($ordernumber, $anfrageart)
    {
        $params = array_merge(
            $this->getDefaultParams($anfrageart),
            $this->getStornoParams($ordernumber)
        );

        return new OrderStornoRequest($params);
    }

    /**
     * @param $changetyp
     * @return array
     */
    protected function getDefaultParams($changetyp)
    {
        return [
            'config' => $this->configData,
            'anfrageart' => $changetyp,
            'bestellwert' => 0,
        ];
    }

    /**
     * @param $ordernumber
     * @return \string[][]
     */
    private function getStornoParams($ordernumber)
    {
        return [
            'referenzen' => [
                'referenztyp' => 'bestellnummer',
                'referenzwert' => $ordernumber,
            ]
        ];
    }
}