<?php
/**
 * Copyright (c) Web Loupe. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

namespace WeloConsorsFinanz\Components;

use Shopware\Bundle\StoreFrontBundle\Service\Core\ContextService;
use Shopware\Bundle\StoreFrontBundle\Struct\ShopContext;
use Shopware\Components\DependencyInjection\Container as DIContainer;

/**
 * Class DependencyProvider
 *
 * @author    Cyprien Nkeneng <cyprien.nkeneng@webloupe.de>
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz\Components
 * @version   1
 */
class DependencyProvider
{
    /**
     * @var DIContainer
     */
    private $container;

    /** @var ContextService */
    private $contextService = null;

    /** @var ShopContext */
    private $shopContext = null;

    /**
     * DependencyProvider constructor.
     *
     * @param DIContainer $container
     */
    public function __construct(DIContainer $container)
    {
        $this->container = $container;
        $this->contextService = $this->container->get('shopware_storefront.context_service');
    }

    /**
     * {@inheritdoc}
     */
    public function getShop()
    {
        if ($this->container->has('shop')) {
            return $this->container->get('shop');
        }

        return null;
    }

    /**
     * {@inheritdoc}
     */
    public function getIdentity()
    {
        if ($this->container->has('Auth')) {
            $getCurrentIdentity = $this->container->get('Auth');
            return $getCurrentIdentity->getIdentity()->id;
        }

        return 0;
    }

    /**
     * {@inheritdoc}
     */
    public function getFrontRequest()
    {
        return $this->container->get('front')->Request();
    }

    /**
     * {@inheritdoc}
     */
    public function getModules()
    {
        if (!$this->container->has('modules')) {
            return null;
        }

        return $this->container->get('modules');
    }

    /**
     * {@inheritdoc}
     */
    public function getBasket()
    {
        return $this->getModules()->Basket();
    }

    /**
     * {@inheritdoc}
     */
    public function getArticles()
    {
        return $this->getModules()->Articles();
    }

    /**
     * {@inheritdoc}
     */
    public function getSession()
    {
        return $this->container->get('session');
    }

    /**
     * {@inheritdoc}
     */
    public function getUserId()
    {
        $customerId = (int)$this->getSession()->get('sUserId');
        return $customerId ?: 0;
    }

    /**
     * {@inheritdoc}
     */
    public function getShopContext()
    {
        $this->initializeShopContext();

        return $this->shopContext;
    }

    /**
     * {@inheritdoc}
     */
    public function getCustomerGroup()
    {
        $this->initializeShopContext();

        return $this->shopContext->getCurrentCustomerGroup();
    }

    /**
     * {@inheritdoc}
     */
    public function initializeShopContext($shopId = null, $currencyId = null, $customerGroupKey = null)
    {
        if (null !== $this->shopContext) {
            return;
        }

        if (null === $shopId) {
            /**
             * Abbruch, wenn kein Shop verfügbar ist
             * Dies ist dann der Fall, wenn der Service bspw. im Backend aufgerufen wird.
             */
            $shop = $this->container->get('shop');
            if(null === $shop) {
                return;
            }

            $this->shopContext = $this->contextService->getShopContext();
        } else {
            $this->shopContext = $this->contextService->createShopContext($shopId, $currencyId, $customerGroupKey);
        }
    }
}
