<?php
/**
 * Copyright (c) Web Loupe. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

namespace WeloConsorsFinanz\Components;

use Enlight_Components_Session_Namespace as ShopwareSession;
use Enlight_Controller_Request_Request;
use sArticles;
use sBasket;
use Shopware\Bundle\StoreFrontBundle\Struct\Customer\Group;
use Shopware\Bundle\StoreFrontBundle\Struct\ShopContext;
use Shopware\Models\Shop\DetachedShop;
use Shopware_Components_Modules;

/**
 * Interface DependencyProviderInterface
 * @package WeloDonationItem\Components
 */
interface DependencyProviderInterface
{
    /**
     * @return DetachedShop
     */
    public function getShop();

    /**
     * @return int
     */
    public function getIdentity();

    /**
     * @return Enlight_Controller_Request_Request
     */
    public function getFrontRequest();

    /**
     * @return Shopware_Components_Modules
     */
    public function getModules();

    /**
     * @return sBasket
     */
    public function getBasket();

    /**
     * @return sArticles
     */
    public function getArticles();

    /**
     * @return ShopwareSession
     */
    public function getSession();

    /**
     * @return mixed
     */
    public function getUserId();

    /**
     * @return ShopContext
     */
    public function getShopContext();

    /**
     * @return Group
     */
    public function getCustomerGroup();

    /**
     * Initialisiert den Shop Contex
     * Da das Backend keinen Shop Scope hat, muss diese Methode für die Verwendung im Backend aufgerufen werden.
     *
     * @param null $shopId
     * @param null $currencyId
     * @param null $customerGroupKey
     */
    public function initializeShopContext($shopId = null, $currencyId = null, $customerGroupKey = null) ;
}