<?php
namespace WeloConsorsFinanz\Components\PaymentMethods;

use DateTime;
use Shopware\Models\Customer\Address;
use Shopware\Models\Customer\Customer;
use ShopwarePlugin\PaymentMethods\Components\GenericPaymentMethod;

/**
 * Class AbstractPaymentMethod
 *
 * @author    Cyprien Nkeneng <cyprien.nkeneng@webloupe.de> - www.webloupe.de
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz\Components\PaymentMethods
 * @link      https://www.webloupe.de
 * @version   1
 */
abstract class AbstractPaymentMethod extends GenericPaymentMethod
{
    protected $pluginData;

    public function __construct()
    {
        $shop = Shopware()->Shop();
        $configuration = Shopware()->Container()->get('shopware.plugin.cached_config_reader')->getByPluginName('WeloConsorsFinanz', $shop);
        $this->pluginData = $configuration;
    }

    protected function getUserPhone($userId)
    {
        $modelManager = Shopware()->Models();
        $user = $modelManager->find(Customer::class, (int)$userId);

        if ($user) {
            /** @var Address $billingAddress */
            $billingAddress = $user->getDefaultBillingAddress();
            if ($billingAddress) {
                return $billingAddress->getPhone();
            }
        }

        return '';
    }

    protected function getUserBirthday($userId)
    {
        return Shopware()->Models()->getConnection()->createQueryBuilder()
            ->select('birthday')
            ->from('s_user')
            ->where('id = :userId')
            ->setParameter('userId', $userId)
            ->execute()
            ->fetchColumn();
    }

    protected function saveDate($userId, $birthday, $type = 'direct')
    {
        if ('direct' == $type && is_array($birthday)) {
            $birthday = $birthday['year'] . '-' . $birthday['month'] . '-' . $birthday['day'];
        }

        Shopware()->Db()->update(
            's_user',
            ['birthday' => $birthday],
            ['id' => $userId]
        );
    }

    protected function savePhone($userId, $phone)
    {
        $modelManager = Shopware()->Models();
        $user = $modelManager->find(Customer::class, (int)$userId);

        if ($user) {
            /** @var Address $billingAddress */
            $billingAddress = $user->getDefaultBillingAddress();
            if ($billingAddress) {
                $billingAddress->setPhone($phone);
                $modelManager->persist($billingAddress);
                $modelManager->persist($user);
                $modelManager->flush();
            }
        }
    }

    /**
     * validates IBAN/BIC fields
     *
     * @param string $ibanbic
     * @return boolean
     */
    protected function isValidIbanBic(string $ibanbic) {

        if (!preg_match('/^[A-Z0-9 ]+$/',
            $ibanbic)) {

            return false;
        }
        else {
            return true;
        }
    }

    protected function validateDOB($date)
    {
        $minAge=strtotime("-18 YEAR");
        $entrantAge= strtotime($date);

        if ($entrantAge < $minAge) {
            return false;
        }

        return true;
    }

    function validateDate($date, $format = 'Y-m-d H:i:s')
    {
//        $date = strtotime($date);
//        die('test '.$date);
        $d = DateTime::createFromFormat($format, $date);

//        $this->dumb($d);
//        die($d->format($format));
        return $d && $d->format($format) == $date;
    }

    function dumb($data) {
        highlight_string("<?php\n " . var_export($data, true) . "?>");
        echo '<script>document.getElementsByTagName("code")[0].getElementsByTagName("span")[1].remove() ;document.getElementsByTagName("code")[0].getElementsByTagName("span")[document.getElementsByTagName("code")[0].getElementsByTagName("span").length - 1].remove() ; </script>';
        die();
    }
}