<?php
/**
 * Copyright (c) Web Loupe. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

namespace WeloConsorsFinanz\Components\PaymentMethods;

/**
 * Class Invoice
 *
 * @author    Cyprien Nkeneng <cyprien.nkeneng@webloupe.de> - www.webloupe.de
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz\Components\PaymentMethods
 * @link      https://www.webloupe.de
 * @version   1
 */
class Invoice extends AbstractPaymentMethod
{
    /**
     * {@inheritdoc}
     */
    public function validate($paymentData)
    {
//        $this->dumb($paymentData);
        $sErrorFlag = [];
        $fields = [
            'ConsorsFinanzInvoicePhone'
        ];

        $birthdayType = $this->pluginData['WeloConsorsFinanzBirthdayType'];
        if ($birthdayType == 'direct') {
            $fields[1]['ConsorsFinanzInvoiceBirthday'] = [
                'day',
                'month',
                'year'
            ];
        } else {
            $fields[1] = 'ConsorsFinanzInvoiceBirthday';
        }

        foreach ($fields as $field) {
            $value = $paymentData[$field] ?: '';
            $value = trim($value);

            if (empty($value)) {
                $sErrorFlag[$field] = true;
            }

            if (is_array($field)) {
                foreach ($field as $key => $date) {
                    foreach ($date as $item) {
                        $value = $paymentData[$key][$item] ?: '';
                        $value = trim($value);
                        if (empty($value)) {
                            $sErrorFlag[$field][$item] = true;
                        }
                    }
                }
            }
        }

        if (count($sErrorFlag) > 0) {
            $sErrorMessages[] = Shopware()->Snippets()->getNamespace('frontend/account/internalMessages')
                ->get('ErrorFillIn', 'Please fill in all red fields');

            return [
                'sErrorFlag' => $sErrorFlag,
                'sErrorMessages' => $sErrorMessages,
            ];
        }

        return [];
    }

    /**
     * {@inheritdoc}
     */
    public function savePaymentData($userId, \Enlight_Controller_Request_Request $request)
    {
        if (0 == (int)$userId) {
            return;
        }

        $session = Shopware()->Session();
        $agb = ($request->getParam('ConsorsFinanzInvoiceAgb') === 'true' ? 1 : 0);
        $session->offsetSet('consorsAgbChecked', $agb);

        $this->saveUserBirthday($userId, $request);
        $this->saveUserPhone($userId, $request);
    }

    /**
     * {@inheritdoc}
     */
    public function getCurrentPaymentDataAsArray($userId)
    {
        return [
            'ConsorsFinanzInvoiceBirthday' => $this->getUserBirthday($userId),
            'ConsorsFinanzInvoicePhone' => $this->getUserPhone($userId),
        ];
    }

    private function saveUserPhone($userId, \Enlight_Controller_Request_Request $request)
    {
        $phone = $request->getParam('ConsorsFinanzInvoicePhone');
        $this->savePhone($userId, $phone);
    }

    private function saveUserBirthday($userId, \Enlight_Controller_Request_Request $request)
    {
        $birthday = $request->getParam('ConsorsFinanzInvoiceBirthdayHidden');
        if (empty($birthday)) {
            $this->saveDate(
                $userId,
                $request->getParam('ConsorsFinanzInvoiceBirthday'),
                $request->getParam('ConsorsFinanzInvoiceBirthdayType')
            );
        }
    }

    function dumb($data) {
        highlight_string("<?php\n " . var_export($data, true) . "?>");
        echo '<script>document.getElementsByTagName("code")[0].getElementsByTagName("span")[1].remove() ;document.getElementsByTagName("code")[0].getElementsByTagName("span")[document.getElementsByTagName("code")[0].getElementsByTagName("span").length - 1].remove() ; </script>';
        die();
    }
}