<?php
/**
 * Copyright (c) Web Loupe. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

namespace WeloConsorsFinanz\Components\Services;

use Shopware\Components\Model\ModelManager;

/**
 * Class ConsorsService
 *
 * @author    Cyprien Nkeneng <cyprien.nkeneng@webloupe.de> - www.webloupe.de
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz\Components\Consors\Services
 * @link      https://www.webloupe.de
 * @version   1
 */
class ConsorsService
{
    /**
     * @var ModelManager
     */
    private $modelManager;

    private $listOfChars = [
        'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'J', 'K', 'L', 'M',
        'N', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z',
        'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l',
        'm', 'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x',
        'y', 'z', '1', '2', '3', '4', '5', '6', '7', '8', '9'
    ];

    /**
     * ConsorsService constructor.
     * @param ModelManager $modelManager
     */
    public function __construct(ModelManager $modelManager)
    {
        $this->modelManager = $modelManager;
    }


    public function getPaymentData($userId = 0, $paymentId = 0)
    {
        if (0 == $userId || 0 == $paymentId) {
            return [];
        }

        return $this->modelManager->getConnection()->createQueryBuilder()
            ->select('*')
            ->from('s_core_payment_data')
            ->where('user_id = :userId')
            ->andWhere('payment_mean_id = :paymentId')
            ->setParameter('userId', $userId)
            ->setParameter('paymentId', $paymentId)
            ->setMaxResults(1)
            ->execute()
            ->fetch();
    }

    public function getNewUserReference($userId)
    {
        do {
            $consorsUserReference = (string) $this->getRandomString(9);
        } while ($this->existUserReference($consorsUserReference));

        $this->modelManager->getConnection()->createQueryBuilder()
            ->update('s_user_attributes')
            ->set('consors_finanz_userreference', ':reference')
            ->where('userID = :userID')
            ->setParameter('userID', (int)$userId)
            ->setParameter('reference', $consorsUserReference)
            ->execute();

        return $consorsUserReference;
    }

    /**
     * @param $consorsUserReference
     * @return bool
     */
    private function existUserReference($consorsUserReference) {
        return (bool) $this->modelManager->getConnection()->createQueryBuilder()
            ->select('*')
            ->from('s_user_attributes')
            ->where('consors_finanz_userreference = :consors_finanz_userreference')
            ->setParameter('consors_finanz_userreference', $consorsUserReference)
            ->execute()
            ->fetch();
    }

    /**
     * This method generates a random string. The $length indicates
     * the length of the resulting string. The $charsToExclude indicates
     * which of the elements are not used. By default 'l', 'i' and '1' are
     * not used.
     *
     * @param integer $length
     * @param string $charsToExclude
     * @return string Random string
     */
    private function getRandomString($length, $charsToExclude = 'li1' ) {
        $characters = [];
        foreach ($this->listOfChars as $char) {
            if (!strstr($charsToExclude, $char)) {
                $characters[] = $char;
            }
        }

        $numberOfCharacters = count($characters);
        $code = '';
        for ($c = 0; $c < $length; $c++) {
            $randIndex = mt_rand(0, $numberOfCharacters-1);
            $code .= $characters[$randIndex];
        }

        return $code;
    }
}