<?php
/**
 * Copyright (c) Web Loupe. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

require_once(__DIR__ . '/ConsorsFinanzBase.php');

use WeloConsorsFinanz\Components\Consors\Api\ConsorsSoapClientFault;
use WeloConsorsFinanz\Components\SettingsTable;

/**
 * Class Shopware_Controllers_Frontend_ConsorsFinanzDebit
 *
 * @author    WEB LOUPE <shopware@webloupe.de>
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @version   1
 */
class Shopware_Controllers_Frontend_ConsorsFinanzDebit extends ConsorsFinanzBase
{
    /**
     * Check if everything is ok and proceed with payment
     *
     * @throws ConsorsSoapClientFault
     * @throws Exception
     */
    public function indexAction()
    {
        $this->loggerService->notify('Debit payment start');
        $this->gateway(SettingsTable::REQUEST_TYPE_DEBIT);
    }

    /**
     * @throws Exception
     */
    public function checkForDebitAction()
    {
        $this->Front()->Plugins()->ViewRenderer()->setNoRender();
        $this->Front()->Plugins()->Json()->setRenderer();
        $view = $this->View();

        $userID = (int)$this->dependencyProvider->getUserId();
        $agb = $this->Request()->getParam('agb');
        $birthday = $this->Request()->getParam('birthday');

        try {
            if (0 != $userID && $birthday && null !== $birthday) {
                $this->saveUserBirthday($userID, $birthday);
            }

            $this->dependencyProvider->getSession()->offsetSet('consorsAgbChecked', $agb);
            $data['status'] = self::STATUS_SUCCESS;
            $view->assign($data);
        } catch (Exception $exception) {
            $data['status'] = self::STATUS_ERROR;
            $this->loggerService->error($exception->getMessage());
            $view->assign($data);
        }
    }
}
