// {block name="backend/customer/controller/detail" append}
Ext.define('Shopware.apps.Customer.ConsorsFinanz.controller.Detail', {
    override: 'Shopware.apps.Customer.controller.Detail',

    /**
     * Event will be fired when the user change the payment combo box which
     * is displayed on bottom of the detail page.
     *
     * @param [object] value     - the new value of the combo box
     * @param [object] container - The field container which contains the debit account fields
     * @return void
     */
    onChangePayment: function (value, container) {
        var me = this;
        var window = me.getDetailWindow();
        var store = window.paymentStore;
        var record = store.getById(value);
        var paymentFieldSet = window.down('customer-debit-field-set');

        switch (record.get('name').toLowerCase()) {
            case 'sepa':
                paymentFieldSet.fieldContainer.show();
                if (paymentFieldSet.fieldContainer.getEl()) {
                    paymentFieldSet.fieldContainer.getEl().fadeIn({
                        opacity: 1,
                        easing: 'easeOut',
                        duration: 500
                    });
                }
                paymentFieldSet.ibanField.hide().allowBlank = true;
                // paymentFieldSet.accountHolderField.hide().allowBlank = true;
                // paymentFieldSet.bankCodeField.hide().allowBlank = true;
                paymentFieldSet.bicField.allowBlank = true;
                break;
            case 'debit':
            case 'weloconsorsfinanzdebit':
                paymentFieldSet.fieldContainer.show();
                if (paymentFieldSet.fieldContainer.getEl()) {
                    paymentFieldSet.fieldContainer.getEl().fadeIn({
                        opacity: 1,
                        easing: 'easeOut',
                        duration: 500
                    });
                }
                paymentFieldSet.fieldContainer.getEl().show().allowBlank = false;
                paymentFieldSet.ibanField.show().allowBlank = false;
                // paymentFieldSet.accountHolderField.show().allowBlank = false;
                paymentFieldSet.bicField.show().allowBlank = false;
                // paymentFieldSet.bankNameField.allowBlank = false;
                break;
            default:
                me.callParent(arguments);
        }
    },

    onSaveCustomer: function (btn) {
        var me = this;
        var window = me.getDetailWindow();
        var form = window.down('form');
        var record = form.getRecord();
        var values = form.getValues();
        var store = window.paymentStore;
        var paymentMean = store.getById(values['paymentId']);
        var paymentData = record.getPaymentData().first();

        if (form.getForm().isValid() && paymentData) {
            switch (paymentMean.get('name')) {
                case 'sepa':
                    values['paymentData[accountHolder]'] = '';
                    values['paymentData[accountNumber]'] = '';
                    values['paymentData[bankCode]'] = '';
                    break;
                case 'debit':
                    values['paymentData[accountNumber]'] = '';
                    values['paymentData[bankCode]'] = '';
                    values['paymentData[useBillingData]'] = false;
                    break;
                case 'weloconsorsfinanzdebit':
                    values['paymentData[accountNumber]'] = '';
                    values['paymentData[bankCode]'] = '';
                    values['paymentData[accountHolder]'] = '';
                    values['paymentData[bankName]'] = '';
                    values['paymentData[useBillingData]'] = false;
                    break;
                default:
                    values['paymentData[accountHolder]'] = '';
                    values['paymentData[accountNumber]'] = '';
                    values['paymentData[bankCode]'] = '';
                    values['paymentData[bankName]'] = '';
                    values['paymentData[bic]'] = '';
                    values['paymentData[iban]'] = '';
                    values['paymentData[useBillingData]'] = false;
                    record['getPaymentDataStore'] = Ext.create('Ext.data.Store', {
                        model: 'Shopware.apps.Customer.model.PaymentData'
                    });

                    break;
            }

            form.getForm().setValues(values);
        }
        me.callParent(arguments);
    }
});
//

// {/block}
