;(function($, window) {
    'use strict';

    $.plugin('ConsorsFinanzInvoice', {
        defaults: {
            hiddenClass: 'is--hidden',

            submitButton: 'submit',

            agbInput: '.consors-finanz-invoice-agb',

            agbLabel: '.consors-finanz-invoice-agb-label',

            url: '',

            /**
             * An object containing the names of all fields that are currently invalid and their resepctive error messages.
             */
            invalidFields: {},
        },

        /** @object - Error status values */
        _status: {
            success: 'success',
            undefined: 'undefined',
        },

        init: function() {
            var me = this;

            me.applyDataAttributes();
            me.registerEvents();
            //
            $.publish('plugin/ConsorsFinanzInvoiceSubmitForm/init', me);
        },

        /**
         * @private
         * @method registerEvents
         */
        registerEvents: function() {
            var me = this;

            me.setupForm();

            // Add listener on changes of the selected payment method to setup the form again
            $.subscribe('plugin/swShippingPayment/onInputChanged', function () {
                me.setupForm();
            });
        },

        setupForm: function () {
            var me = this;

            me.formEl('*.consors-finanz-invoice-agb-label ').swModalbox();
            me.formEl('*.datepicker').swDatePicker();

            this.$body = this.$el;
            this.invalidFields = {};
            this.updateValidationErrors();

            if (this.getActiveConsorsFinanzInvoiceForm()) {
                $('.consors-finanz-invoice-form').show();
                $('#invoice-birthday_day').addClass('is--required');
                $('#invoice-birthday_month').addClass('is--required');
                $('#invoice-birthday_year').addClass('is--required');


                $('.consors-finanz-debit-form').hide();
                $('#debit-birthday_day').removeClass('is--required').removeAttr('required');
                $('#debit-birthday_month').removeClass('is--required').removeAttr('required');
                $('#debit-birthday_year').removeClass('is--required').removeAttr('required');

                this.observeForm();
            }
        },

        observeForm: function () {
            var me = this;

            me.formEl('input[class^="consors-finanz-"]').each(function () {
                // Save the current value and add listener
                var elem = $(this);
                elem.data('oldVal', elem.val());
                elem.on('propertychange keyup input paste change', { scope: me }, me.onFieldChange);
            });

            // me.findForm().on('submit', { scope: me }, me.onFormSubmission);
            $('#shippingPaymentForm').one('submit', { scope: me }, this.onFormSubmission.bind(this));
        },

        onFormSubmission: function(event) {
            var me = event.data.scope;

            me.resetErrorDiv();

            // Prevent the form from being submitted until the card details are validated and the customer is approved
            event.preventDefault();

            // Trigger the validation of all fields
            me.formEl('input[class^="consors-finanz-"]').each(function () {
                $(this).trigger('propertychange', [ true ]);
            });

            // Check for invalid fields
            if (Object.keys(me.invalidFields).length > 0) {
                return;
            }

            me.resetErrorDiv();

            // Prevent the form from being submitted until the card details are validated and the customer is approved
            event.preventDefault();

            // Check for invalid fields
            if (Object.keys(me.invalidFields).length > 0) {
                return;
            }

            me.findForm().submit();
        },

        /**
         * Determines the error message based on the given 'errorCode' and 'message' and triggers
         * an update of the displayed validation errors.
         *
         * @param String fieldId
         * @param String errorCode (optional) The code used to find a localised error message.
         * @param String message (optional) The fallback error message used in case no 'errorCode' is provided or no
         *        respective, localised description exists.
         */
        markFieldInvalid: function(fieldId, errorCode, message) {
            this.invalidFields[fieldId] = message || 'Unknown error';
            this.updateValidationErrors();
        },

        /**
         * Removes all validation errors for the field with the given 'fieldId' and triggers an update of the displayed
         * validation errors.
         *
         * @param String fieldId
         */
        markFieldValid: function(fieldId) {
            delete this.invalidFields[fieldId];
            this.updateValidationErrors();
        },

        /**
         * Validates the field value to not be empty. If the validation fails, the field is marked invalid.
         *
         * @param Event event
         * @param boolean|undefined force
         */
        onFieldChange: function (event, force) {
            var me = event.data.scope,
                elem = $(this),
                name = elem.attr('name'),
                $abgLabel = $(me.opts.agbLabel);

            if ('invoice-agb' !== name) {
                // Check if value has changed, if 'force' is not set
                if (!force && elem.data('oldVal') == elem.val()) {
                    return;
                }
                elem.data('oldVal', elem.val());

                // Validate the field
                if (elem.val().trim().length === 0) {
                    elem.addClass('instyle_error has--error');
                    me.markFieldInvalid(name, ('invalid_' + name));
                } else {
                    elem.removeClass('instyle_error has--error');
                    me.markFieldValid(name);
                }
            } else {
                if (!this.checked) {
                    elem.addClass('instyle_error has--error');
                    $abgLabel.addClass('has--error');
                    me.markFieldInvalid(name, ('invalid_' + name), 'Sie müssen die AGB akzeptieren!');
                } else {
                    elem.removeClass('instyle_error has--error');
                    $abgLabel.removeClass('has--error');
                    me.markFieldValid(name);
                }
            }
        },

        /**
         * Tries to find a consors finanz form for the currently active payment method. That is, if a consors finanz payment
         * method is selected, its form is returned, otherwise returns null.
         *
         * @return jQuery|null
         */
        getActiveConsorsFinanzInvoiceForm: function() {
            var form = $('input[id^="payment_mean"]:checked').closest('.payment--method').find('.consors-finanz-invoice-form');

            return (form.length > 0) ? form.first() : null;
        },

        /**
         * Sets the given message in the general error box and scrolls the page to make it visible.
         *
         * @param String message A Stripe error message.
         */
        handleError: function(message) {
            // Display the error information above the credit card form and scroll to its position
            this.formEl('.consors-finanz-error-box').show().children('.error-content').html(message);
            $('body').animate({
                scrollTop: (this.getActiveConsorsFinanzInvoiceForm().offset().top - 100)
            }, 500);
        },

        /**
         * Sets the given message in the general error box and scrolls the page to make it visible.
         *
         * @param String message A Stripe error message.
         */
        resetErrorDiv: function() {
            this.formEl('.consors-finanz-error-box').hide();
        },

        /**
         * Finds both submit buttons on the page and adds the 'disabled' attribute as well as the loading indicator to each
         * of them.
         */
        setSubmitButtonsLoading: function() {
            // Reset the button first to prevent it from being added multiple loading indicators
            this.resetSubmitButtons();
            $('#shippingPaymentForm button[type="submit"], .confirm--actions button[form="shippingPaymentForm"]').each(function() {
                $(this).html($(this).text() + '<div class="js--loading"></div>').attr('disabled', 'disabled');
            });
        },

        /**
         * Finds both submit buttons on the page and resets them by removing the 'disabled' attribute as well as the
         * loading indicator.
         */
        resetSubmitButtons: function() {
            $('#shippingPaymentForm button[type="submit"], .confirm--actions button[form="shippingPaymentForm"]').each(function() {
                $(this).removeAttr('disabled').find('.js--loading').remove();
            });
        },

        updateValidationErrors: function() {
            var me = this,
                errorBox = me.formEl('.consors-finanz-validation-error-box'),
                boxContent = errorBox.find('.error-content');
            boxContent.empty();
            if (Object.keys(me.invalidFields).length > 0) {
                // Update the error box message and make it visible
                var listEl = $('<ul></ul>')
                    .addClass('alert--list')
                    .appendTo(boxContent);
                Object.keys(me.invalidFields).forEach(function(key) {
                    var row = $('<li></li>')
                        .addClass('list--entry')
                        .text(me.invalidFields[key])
                        .appendTo(listEl);
                });
                errorBox.show();
            } else {
                errorBox.hide();
            }
        },

        formEl: function (selector) {
            var form = this.getActiveConsorsFinanzInvoiceForm();
            return (form) ? form.find(selector) : $('consors_finanz_invoice_not_found');
        },

        /**
         * @return jQuery The main payment selection form element.
         */
        findForm: function () {
            return $('#shippingPaymentForm');
        }
    });

window.StateManager.addPlugin('*[data-consors-finanz-invoice="true"]', 'ConsorsFinanzInvoice');
})(jQuery, window);
