<?php
/**
 * Copyright (c) Web Loupe. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

namespace WeloConsorsFinanz\Subscriber;

use Enlight\Event\SubscriberInterface;
use Enlight_Controller_ActionEventArgs as ActionEventArgs;
use WeloConsorsFinanz\Components\Configuration;
use WeloConsorsFinanz\Components\DependencyProvider;
use WeloConsorsFinanz\Components\Services\ConsorsService;

/**
 * Class Checkout
 *
 * @author    Cyprien Nkeneng <cyprien.nkeneng@webloupe.de> - www.webloupe.de
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz\Subscriber
 * @link      https://www.webloupe.de
 * @version   1
 */
class Account implements SubscriberInterface
{
    /**
     * @var Configuration
     */
    private $configuration;
    /**
     * @var ConsorsService
     */
    private $consorsService;
    /**
     * @var DependencyProvider
     */
    private $dependencyProvider;

    /**
     * Checkout constructor.
     * @param Configuration      $configuration
     * @param ConsorsService     $consorsService
     * @param DependencyProvider $dependencyProvider
     */
    public function __construct(
        Configuration $configuration,
        ConsorsService $consorsService,
        DependencyProvider $dependencyProvider
    ) {
        $this->configuration = $configuration;
        $this->consorsService = $consorsService;
        $this->dependencyProvider = $dependencyProvider;
    }

    public static function getSubscribedEvents()
    {
        return [
            'Enlight_Controller_Action_PostDispatch_Frontend_Account' => [
                ['onAccountPostDispatch', 1000],
            ],
        ];
    }

    /**
     * @param ActionEventArgs $args
     * @throws \Exception
     */
    public function onAccountPostDispatch(ActionEventArgs $args)
    {
        $request = $args->getRequest();
        $view = $args->getSubject()->View();
        $availableActions = ['payment'];
        $wConsorsFinanz = $this->configuration->getPluginData();

        $sUserData = $view->getAssign('sUserData');
        $paymentId = $sUserData['additional']['payment']['id'];
        $userId = (int)$sUserData['additional']['user']['id'];
        $birthday = $sUserData['additional']['user']['birthday'];
        $phone = $sUserData['billingaddress']['phone'];

//        $this->dumb($sUserData);
        if (!in_array(strtolower($request->getActionName()), $availableActions, true)) {
            return;
        }

        if (!$wConsorsFinanz['isActive']) {
            return;
        }

        $wConsorsFinanz = array_merge(
            $wConsorsFinanz,
            [
                'paymentData' => $this->consorsService->getPaymentData($userId, $paymentId),
                'phone' => $phone,
                'birthday' => $birthday,
                'hasBirthday' => (bool)($birthday != null),
                'consorsAgbChecked' => (bool)$this->dependencyProvider->getSession()->offsetGet('consorsAgbChecked')
            ]
        );

        $view->assign('wConsorsFinanz', $wConsorsFinanz);
    }

    function dumb($data) {
        highlight_string("<?php\n " . var_export($data, true) . "?>");
        echo '<script>document.getElementsByTagName("code")[0].getElementsByTagName("span")[1].remove() ;document.getElementsByTagName("code")[0].getElementsByTagName("span")[document.getElementsByTagName("code")[0].getElementsByTagName("span").length - 1].remove() ; </script>';
        die();
    }
}
