<?php
/**
 * Copyright (c) Web Loupe. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

namespace WeloConsorsFinanz\Subscriber;

use Enlight\Event\SubscriberInterface;
use Enlight_Components_Session_Namespace;
use Enlight_Controller_ActionEventArgs as ActionEventArgs;
use Shopware\Components\Model\ModelManager;
use WeloConsorsFinanz\Components\Configuration;
use WeloConsorsFinanz\Components\Consors\Api\ConsorsSoapClientFault;
use WeloConsorsFinanz\Components\Consors\Services\BoniCheckService;
use WeloConsorsFinanz\Components\Consors\Services\ChangeService;
use WeloConsorsFinanz\Components\Consors\Services\OrderStornoService;
use WeloConsorsFinanz\Components\DependencyProvider;
use WeloConsorsFinanz\Components\DependencyProviderInterface;
use WeloConsorsFinanz\Components\Services\ConsorsService;
use WeloConsorsFinanz\Components\SettingsTable;

/**
 * Class Checkout
 *
 * @author    Cyprien Nkeneng <cyprien.nkeneng@webloupe.de> - www.webloupe.de
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz\Subscriber
 * @link      https://www.webloupe.de
 * @version   1
 */
class Checkout implements SubscriberInterface
{
    /**
     * @var Configuration
     */
    private $configuration;
    /**
     * @var ModelManager
     */
    private $modelManager;
    /**
     * @var BoniCheckService
     */
    private $boniCheckService;

    /**
     * @var DependencyProviderInterface
     */
    private $dependencyProvider;
    /**
     * @var OrderStornoService
     */
    private $orderStornoService;
    /**
     * @var Enlight_Components_Session_Namespace
     */
    private $session;
    /**
     * @var ChangeService
     */
    private $changeService;
    /**
     * @var ConsorsService
     */
    private $consorsService;

    /**
     * Checkout constructor.
     * @param Configuration                        $configuration
     * @param ModelManager                         $modelManager
     * @param BoniCheckService                     $boniCheckService
     * @param DependencyProvider                   $dependencyProvider
     * @param OrderStornoService                   $orderStornoService
     * @param Enlight_Components_Session_Namespace $session
     * @param ChangeService                        $changeService
     * @param ConsorsService                       $consorsService
     */
    public function __construct(
        Configuration $configuration,
        ModelManager $modelManager,
        BoniCheckService $boniCheckService,
        DependencyProvider $dependencyProvider,
        OrderStornoService $orderStornoService,
        Enlight_Components_Session_Namespace $session,
        ChangeService $changeService,
        ConsorsService $consorsService
    ) {
        $this->configuration = $configuration;
        $this->modelManager = $modelManager;
        $this->boniCheckService = $boniCheckService;
        $this->dependencyProvider = $dependencyProvider;
        $this->orderStornoService = $orderStornoService;
        $this->session = $session;
        $this->changeService = $changeService;
        $this->consorsService = $consorsService;
    }

    public static function getSubscribedEvents()
    {
        return [
            'Enlight_Controller_Action_PostDispatch_Frontend_Checkout' => [
                ['onCheckoutPostDispatch', 1000],
            ],
        ];
    }

    /**
     * @param ActionEventArgs $args
     * @throws \Exception
     */
    public function onCheckoutPostDispatch(ActionEventArgs $args)
    {
        $request = $args->getRequest();
        $availableActions = ['shippingpayment', 'confirm'];
        $wConsorsFinanz = $this->configuration->getPluginData();

        if (!in_array(strtolower($request->getActionName()), $availableActions, true)) {
            return;
        }

        if (!$wConsorsFinanz['isActive']) {
            return;
        }

        switch ($request->getActionName()) {
            case 'confirm': {
                $this->handleConfirm($args, $wConsorsFinanz);
            }
            break;
            case 'shippingPayment': {
                $this->handleShippingPayment($args, $wConsorsFinanz);
            }
            break;
        }
    }

    private function handleShippingPayment($args, $wConsorsFinanz)
    {
        $request = $args->getRequest();
        $view = $args->getSubject()->View();
        $sUserData = $view->getAssign('sUserData');
        $paymentId = $sUserData['additional']['payment']['id'];
        $userId = (int)$sUserData['additional']['user']['id'];
        $birthday = $sUserData['additional']['user']['birthday'];
        $phone = $sUserData['billingaddress']['phone'];

//        $this->dumb($sUserData);
        if (0 == $userId) {
            $userId = (int)$this->dependencyProvider->getUserId();
        }

        $error = $request->getParam('wConsorsFinanzErrorCode');

        if (isset($error)) {
            $view->assign('wConsorsFinanzErrorCode', $error);
        }

        $wConsorsFinanz = array_merge(
            $wConsorsFinanz,
            [
                'paymentData' => $this->consorsService->getPaymentData($userId, $paymentId),
                'phone' => $phone,
                'birthday' => $birthday,
                'hasBirthday' => (bool)($birthday != null),
                'consorsAgbChecked' => (bool)$this->dependencyProvider->getSession()->offsetGet('consorsAgbChecked')
            ]
        );

        $view->assign('wConsorsFinanz', $wConsorsFinanz);
    }

    /**
     * @param ActionEventArgs $args
     * @param                 $wConsorsFinanz
     * @throws ConsorsSoapClientFault
     * @throws \Exception
     */
    private function handleConfirm(ActionEventArgs $args, $wConsorsFinanz)
    {
        $action = $args->getSubject();
        $view = $args->getSubject()->View();
        $sUserData = $view->getAssign('sUserData');
        $sOrderVariables = $view->getAssign();

        $wConsorsFinanzPaymentIds = [$wConsorsFinanz['invoicePaymentMethodId'], $wConsorsFinanz['debitPaymentMethodId']];
        $paymentId = $sUserData['additional']['payment']['id'];
        $userId = (int)$sUserData['additional']['user']['id'];
        $birthday = $sUserData['additional']['user']['birthday'];

//        die('weiter');
        if (0 == $userId) {
            $userId = (int)$this->dependencyProvider->getUserId();
        }

//        $orderChangeResponse = $this->changeService->change([],SettingsTable::CHANGE_TYPE_BUCHUNG_BONICHECK);
//        die('here '. $orderChangeResponse->getFehlergrund() . ' and text = ' . $orderChangeResponse->getFehlertext());

        $errorCode = 0;
        if (in_array($paymentId, $wConsorsFinanzPaymentIds)) {
            $wConsorsFinanz = array_merge(
                $wConsorsFinanz, ['isConsorsPayment' => true]
            );

            if (!$birthday) {
                return $action->redirect([
                    'controller' => 'checkout',
                    'action' => 'shippingPayment',
                    'wConsorsFinanzErrorCode' => 23,
                ]);
                return;
            } else {
                if (!$this->dependencyProvider->getSession()->offsetGet('consorsAgbChecked')) {
                    return $action->redirect([
                        'controller' => 'checkout',
                        'action' => 'shippingPayment',
                        'wConsorsFinanzErrorCode' => 22,
                    ]);
                    return;
                }

                if ($paymentId == $wConsorsFinanz['invoicePaymentMethodId']) {
                    $requestType = SettingsTable::REQUEST_TYPE_INVOICE;
                } else {
                    $requestType = SettingsTable::REQUEST_TYPE_DEBIT;
                    $paymentData = $this->consorsService->getPaymentData($userId, $paymentId);

                    if (!$paymentData) {
                        $errorCode = 24;
                        return $action->redirect([
                            'controller' => 'checkout',
                            'action' => 'shippingPayment',
                            'wConsorsFinanzErrorCode' => $errorCode,
                        ]);
                        return;
                    }
                }

                $boni2CheckResponse = $this->boniCheckService->checkBoni($sOrderVariables, $requestType);
//                $this->dumb($boni2CheckResponse);
                $errorCode = $boni2CheckResponse->getFehlergrund();
            }

            if (0 !== (int)$errorCode) {
                if (4 == $errorCode) {
                    $this->consorsService->getNewUserReference($userId);
                }
                $action->redirect([
                    'controller' => 'checkout',
                    'action' => 'shippingPayment',
                    'wConsorsFinanzErrorCode' => $errorCode,
                ]);
            }
        }

        $view->assign('wConsorsFinanz', $wConsorsFinanz);
    }

    function dumb($data) {
        highlight_string("<?php\n " . var_export($data, true) . "?>");
        echo '<script>document.getElementsByTagName("code")[0].getElementsByTagName("span")[1].remove() ;document.getElementsByTagName("code")[0].getElementsByTagName("span")[document.getElementsByTagName("code")[0].getElementsByTagName("span").length - 1].remove() ; </script>';
        die();
    }
}
