<?php
/**
 * Copyright (c) Web Loupe. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

namespace WeloConsorsFinanz\Subscriber\ControllerRegistration;

use Enlight\Event\SubscriberInterface;

/**
 * Class Frontend
 *
 * @author    Cyprien Nkeneng <cyprien.nkeneng@webloupe.de>
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz\Subscriber\ControllerRegistration
 * @version   1
 */
class Frontend implements SubscriberInterface
{
    /**
     * @var string
     */
    private $pluginDirectory;

    /**
     * @param string $pluginDirectory
     */
    public function __construct($pluginDirectory)
    {
        $this->pluginDirectory = $pluginDirectory;
    }

    /**
     * {@inheritdoc}
     */
    public static function getSubscribedEvents()
    {
        return [
            'Enlight_Controller_Dispatcher_ControllerPath_Frontend_ConsorsFinanz' => 'onGetConsorsFinanzControllerPath',
            'Enlight_Controller_Dispatcher_ControllerPath_Frontend_ConsorsFinanzDebit' => 'onGetConsorsFinanzDebitControllerPath',
            'Enlight_Controller_Dispatcher_ControllerPath_Frontend_ConsorsFinanzInvoice' => 'onGetConsorsFinanzInvoiceControllerPath',
        ];
    }

    /**
     * Handles the Enlight_Controller_Dispatcher_ControllerPath_Frontend_ConsorsFinanzInvoice event.
     * Returns the path to the frontend controller.
     *
     * @return string
     */
    public function onGetConsorsFinanzControllerPath()
    {
        return $this->pluginDirectory . '/Controllers/Frontend/ConsorsFinanz.php';
    }

    /**
     * Handles the Enlight_Controller_Dispatcher_ControllerPath_Frontend_ConsorsFinanzInvoice event.
     * Returns the path to the frontend controller.
     *
     * @return string
     */
    public function onGetConsorsFinanzInvoiceControllerPath()
    {
        return $this->pluginDirectory . '/Controllers/Frontend/ConsorsFinanzInvoice.php';
    }

    /**
     * Handles the Enlight_Controller_Dispatcher_ControllerPath_Frontend_ConsorsFinanzDebit event.
     * Returns the path to the installments controller.
     *
     * @return string
     */
    public function onGetConsorsFinanzDebitControllerPath()
    {
        return $this->pluginDirectory . '/Controllers/Frontend/ConsorsFinanzDebit.php';
    }
}
