<?php
/**
 * Copyright (c) Web Loupe. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

namespace WeloConsorsFinanz\Subscriber;

use Doctrine\Common\Collections\ArrayCollection;
use Enlight\Event\SubscriberInterface;
use Shopware\Components\Theme\LessDefinition;

/**
 * Class Less
 *
 * @author    Cyprien Nkeneng <cyprien.nkeneng@webloupe.de>
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz\Subscriber
 * @version   1
 */
class Less implements SubscriberInterface
{
    /**
     * @var string
     */
    private $pluginDirectory;

    /**
     * @param string $pluginDirectory
     */
    public function __construct($pluginDirectory)
    {
        $this->pluginDirectory = $pluginDirectory;
    }

    /**
     * {@inheritdoc}
     */
    public static function getSubscribedEvents()
    {
        return [
            'Theme_Compiler_Collect_Plugin_Less' => 'onCollectLessFiles',
            'Theme_Compiler_Collect_Plugin_Javascript' => 'onCollectPluginJavascriptFiles',
        ];
    }

    /**
     * @return ArrayCollection
     */
    public function onCollectLessFiles()
    {
        $less = new LessDefinition(
            //configuration
            [],
            //less files to compile
            [$this->pluginDirectory . '/Resources/views/frontend/_public/src/less/all.less'],
            //import directory
            $this->pluginDirectory
        );

        return new ArrayCollection([$less]);
    }

    /**
     * @return ArrayCollection
     */
    public function onCollectPluginJavascriptFiles()
    {
        return new ArrayCollection([
            $this->pluginDirectory . '/Resources/views/frontend/_public/src/js/consors_finanz_debit.js',
            $this->pluginDirectory . '/Resources/views/frontend/_public/src/js/consors_finanz_invoice.js',
        ]);
    }
}
