<?php
namespace WeloConsorsFinanz;

use Shopware\Components\Plugin;
use Shopware\Components\Plugin\Context\ActivateContext;
use Shopware\Components\Plugin\Context\DeactivateContext;
use Shopware\Components\Plugin\Context\InstallContext;
use Shopware\Components\Plugin\Context\UninstallContext;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use WeloConsorsFinanz\Bootstrap\Attributes;
use WeloConsorsFinanz\Bootstrap\Database;
use WeloConsorsFinanz\Bootstrap\Installer;

/**
 * Class WeloConsorsFinanz
 *
 * @author    Cyprien Nkeneng <cyprien.nkeneng@webloupe.de>
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz
 * @version   1
 */
class WeloConsorsFinanz extends Plugin
{
    /**
     * @param ContainerBuilder $container
     *
     * @return void
     */
    public function build(ContainerBuilder $container)
    {
        $container->setParameter('welo_consors_finanz.plugin_dir', $this->getPath());
        $container->setParameter('welo_consors_finanz.namespace', $this->getName());
        parent::build($container);
    }

    /**
     * {@inheritdoc}
     */
    public function install(InstallContext $context)
    {
        $this->getInstaller()->install();
    }

    /**
     * {@inheritdoc}
     */
    public function uninstall(UninstallContext $context)
    {
        $installer = $this->getInstaller();
        if (!$context->keepUserData()) {
            $installer->uninstall();
        }
        $context->scheduleMessage('Plugin successfully uninstalled');
        $context->scheduleClearCache(UninstallContext::CACHE_LIST_ALL);
    }

    /**
     * {@inheritdoc}
     */
    public function activate(ActivateContext $context)
    {
        $context->scheduleMessage('Please configure the plugin and compile the theme.');
        parent::activate($context);
    }

    /**
     * {@inheritdoc}
     */
    public function deactivate(DeactivateContext $context)
    {
        $this->getDatabase()->deactivatePaymentMethods();
        parent::deactivate($context);
    }

    /**
     * @return Installer
     */
    public function getInstaller()
    {
        $attribute = new Attributes(
            $this->container->get('shopware_attribute.crud_service'),
            $this->container->get('models')
        );

        $database = new Database(
            $this->container->get('models'),
            $this->getPath()
        );

        return new Installer(
            $attribute,
            $database
        );
    }

    /**
     * @return Database
     */
    public function getDatabase()
    {
        return new Database(
            $this->container->get('models'),
            $this->getPath()
        );
    }
}
