<?php

namespace MilleConsorsFinanz\Components\Services;

use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\OptimisticLockException;
use Doctrine\ORM\ORMException;
use Exception;
use MilleConsorsFinanz\Models\Financing\Financing;
use MilleConsorsFinanz\Models\Financing\Repository as FinancingRepository;
use MilleConsorsFinanz\Struct\Notification;
use Shopware\Components\Model\ModelManager;
use Shopware\Models\Order\Status;

class FinancingService
{
    /**
     * @var ModelManager
     */
    private $modelManager;

    /**
     * @var StatusService
     */
    private $statusService;

    /**
     * @var FinancingRepository
     */
    private $financingRepository;

    /**
     * @var EntityRepository
     */
    private $statusRepository;

    /**
     * @param ModelManager $modelManager
     * @param StatusService $statusService
     */
    public function __construct(
        ModelManager $modelManager,
        StatusService $statusService
    ) {
        $this->modelManager = $modelManager;
        $this->statusService = $statusService;

        $this->financingRepository = $modelManager->getRepository(Financing::class);
        $this->statusRepository = $modelManager->getRepository(Status::class);
    }

    /**
     * @param Financing $financing
     * @param Notification $notification
     *
     * @return Financing
     * @throws ORMException
     * @throws OptimisticLockException
     * @throws Exception
     */
    public function updateFinancingFromNotification(Financing $financing, Notification $notification): Financing
    {
        if ($this->shouldUpdateFinancingTransactionId($notification, $financing)) {
            $financing->setTransactionId($notification->getTransactionId());
        }

        $status = $this->statusService->getStatusFromNotification($notification);

        $financing->setStatus($status->getId());
        $financing->setUpdatedTimeToNow();

        $this->modelManager->persist($financing);
        $this->modelManager->flush();

        return $financing;
    }

    /**
     * @param Notification $notification
     * @param Financing $financing
     * @return bool
     */
    private function shouldUpdateFinancingTransactionId(Notification $notification, Financing $financing)
    {
        return $notification->hasTransactionId()
               && (!$financing->hasTransactionId() || $this->isFinancingTransactionIdTemporary($financing));
    }

    /**
     * @param Financing $financing
     *
     * @return bool
     */
    private function isFinancingTransactionIdTemporary(Financing $financing): bool
    {
        return $financing->getUniqueId() == $financing->getTransactionId();
    }
}
