<?php

namespace MilleConsorsFinanz\Components\Services;

use MilleConsorsFinanz\Components\Settings\SettingsProvider;
use MilleConsorsFinanz\Struct\FinancingContextInterface;
use Shopware\Components\Logger;

class LogService implements LogServiceInterface
{
    /**
     * @var string
     */
    const MESSAGE_PREFIX = 'Consors Finanz: ';

    /**
     * @var Logger
     */
    private $logger;

    /**
     * @var SettingsProvider
     */
    private $settingsProvider;

    /**
     * @param Logger $logger
     * @param SettingsProvider $settingsProvider
     */
    public function __construct(
        Logger $logger,
        SettingsProvider $settingsProvider
    ) {
        $this->logger = $logger;
        $this->settingsProvider = $settingsProvider;
    }

    /**
     * {@inheritdoc}
     */
    public function error(string $message, array $context, FinancingContextInterface $financingContext)
    {
        if ($this->settingsProvider->isLoggingEnabled($financingContext)) {
            $this->logger->error(self::MESSAGE_PREFIX . $message, $context);
        }
    }

    /**
     * {@inheritdoc}
     */
    public function info(string $message, array $context, FinancingContextInterface $financingContext)
    {
        if ($this->settingsProvider->isLoggingEnabled($financingContext)) {
            $this->logger->info(self::MESSAGE_PREFIX . $message, $context);
        }
    }
}
