<?php

namespace MilleConsorsFinanz\Components\Services;

use Enlight_Controller_Request_Request;
use MilleConsorsFinanz\Components\NotificationStatus;
use MilleConsorsFinanz\Components\NotificationStatusDetail;
use MilleConsorsFinanz\Components\Settings\SettingsProvider;
use MilleConsorsFinanz\Struct\Notification;

class NotificationService
{
    /**
     * @var SettingsProvider
     */
    private $settingsProvider;

    /**
     * NotificationService constructor.
     *
     * @param SettingsProvider $settingsProvider
     */
    public function __construct(SettingsProvider $settingsProvider)
    {
        $this->settingsProvider = $settingsProvider;
    }

    /**
     * @param $request Enlight_Controller_Request_Request
     * @return Notification
     */
    public function createNotificationFromRequest(Enlight_Controller_Request_Request $request): Notification
    {
        $notification = new Notification();

        $notification->setTransactionId($request->getParam('transaction_id', ''));
        $notification->setUniqueId($request->getParam('uid', ''));
        $notification->setOrderId($request->getParam('order_id', ''));
        $notification->setStatus($request->getParam('status', ''));
        $notification->setStatusDetail($request->getParam('status_detail', ''));
        $notification->setDuration((int) $request->getParam('duration', 0));
        $notification->setHash($request->getParam('hash', ''));

        return $notification;
    }

    /**
     * @param Notification $notification
     * @param string $hashKey
     *
     * @return bool
     */
    public function validateNotification(Notification $notification, string $hashKey): bool
    {
        if (!$this->validateNotificationStatus($notification->getStatus(), $notification->getStatusDetail())) {
            return false;
        }

        if (!$this->validateNotificationHash($notification->getHash(), $hashKey)) {
            return false;
        }

        return true;
    }

    /**
     * @param string $status
     * @param string $statusDetail
     * @return bool
     */
    private function validateNotificationStatus(string $status, string $statusDetail): bool
    {
        if (!in_array($status, NotificationStatus::getAllValues())) {
            return false;
        }

        if ($status == NotificationStatus::ERROR && !in_array($statusDetail, NotificationStatusDetail::getAllValues())) {
            return false;
        }

        return true;
    }

    /**
     * @param string $notificationHash
     * @param string $hashKey
     *
     * @return bool
     */
    private function validateNotificationHash(string $notificationHash, string $hashKey): bool
    {
        $notifyUrl = 'http' . (isset($_SERVER['HTTPS']) ? 's' : '') . '://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
        $notifyUrlWithoutHashParameter = substr($notifyUrl, 0, strpos($notifyUrl, '&hash='));
        $hash = hash_hmac('sha512', $notifyUrlWithoutHashParameter, $hashKey);

        return $hash == $notificationHash;
    }
}
