<?php

namespace MilleConsorsFinanz\Components\Services;

use Doctrine\ORM\EntityRepository;
use Exception;
use MilleConsorsFinanz\Components\NotificationStatus;
use MilleConsorsFinanz\Components\NotificationStatusDetail;
use MilleConsorsFinanz\Components\PaymentStatus;
use MilleConsorsFinanz\Struct\Notification;
use Shopware\Components\Model\ModelManager;
use Shopware\Models\Order\Status;

class StatusService
{
    /**
     * @var array
     */
    private $notificationStatusToPaymentStatusMap = [
        NotificationStatus::PROPOSAL => PaymentStatus::PROPOSAL,
        NotificationStatus::SUCCESS => PaymentStatus::WAITING_FOR_DOCUMENTS,
        NotificationStatus::ACCEPTED => PaymentStatus::ACCEPTED
    ];

    /**
     * @var array
     */
    private $notificationStatusDetailToPaymentStatusMap = [
        NotificationStatusDetail::CANCELLED => PaymentStatus::CANCELLED,
        NotificationStatusDetail::TIMEOUT => PaymentStatus::REFUSED,
        NotificationStatusDetail::DECLINED => PaymentStatus::REFUSED,
        NotificationStatusDetail::BAD_REQUEST => PaymentStatus::REFUSED
    ];

    /**
     * @var ModelManager
     */
    private $modelManager;

    /**
     * @var EntityRepository
     */
    private $statusRepository;

    /**
     * @param ModelManager $modelManager
     */
    public function __construct(ModelManager $modelManager) {
        $this->modelManager = $modelManager;

        $this->statusRepository = $modelManager->getRepository(Status::class);
    }

    /**
     * @param Notification $notification
     * @return Status
     * @throws Exception
     */
    public function getStatusFromNotification(Notification $notification): Status
    {
        $statusName = $this->mapNotificationToStatusName($notification);

        return $this->findStatusByName($statusName);
    }

    /**
     * @param Notification $notification
     * @return string
     * @throws Exception
     */
    private function mapNotificationToStatusName(Notification $notification): string
    {
        $status = $notification->getStatus();
        $statusDetail = $notification->getStatusDetail();

        if (array_key_exists($status, $this->notificationStatusToPaymentStatusMap)) {
            return $this->notificationStatusToPaymentStatusMap[$status];
        }

        if ($status == NotificationStatus::ERROR && array_key_exists($statusDetail, $this->notificationStatusDetailToPaymentStatusMap)) {
            return $this->notificationStatusDetailToPaymentStatusMap[$statusDetail];
        }

        throw new Exception();
    }

    /**
     * @param string $statusName
     * @return Status
     * @throws Exception
     */
    public function findStatusByName(string $statusName): Status
    {
        /** @var Status $status */
        $status = $this->statusRepository->findOneBy(['name' => $statusName]);

        if (!$status) {
            throw new Exception('Could not find the payment status with the name "' . $statusName . '""');
        }

        return $status;
    }
}
