<?php

use Doctrine\ORM\OptimisticLockException;
use Doctrine\ORM\ORMException;
use MilleConsorsFinanz\Models\Settings\Repository as SettingsRepository;
use MilleConsorsFinanz\Models\Settings\Settings;

class Shopware_Controllers_Backend_MilleConsorsFinanzSettings extends Shopware_Controllers_Backend_ExtJs
{
    /**
     * @throws Exception
     */
    public function preDispatch()
    {
        if (!in_array($this->Request()->getActionName(), array('index', 'load'))) {
            $this->Front()->Plugins()->Json()->setRenderer(true);
        }
    }

    /**
     * @throws Exception
     */
    public function loadAllAction()
    {
        $settings = $this->getSettingsRepository()->findAllAsArray();

        $this->View()->assign([
            'success' => true,
            'settings' => $settings
        ]);
    }

    /**
     * @throws ORMException
     * @throws OptimisticLockException
     * @throws Exception
     */
    public function saveAction()
    {
        $settingsData = json_decode($this->Request()->getParam('settings'), true);

        if (!$settingsData) {
            $this->View()->assign([
                'success' => false
            ]);

            return;
        }

        foreach ($settingsData as $settingData) {
            $setting = $this->getSettingsRepository()->findOneBy(['countryIso' => $settingData['countryIso']]);

            if (!$setting) {
                $setting = new Settings();
            }

            $setting->setDataFromArray($settingData);
            $this->getModelManager()->persist($setting);
        }

        $this->getModelManager()->flush();

        $this->View()->assign([
            'success' => true
        ]);
    }

    /**
     * @return SettingsRepository
     * @throws Exception
     */
    private function getSettingsRepository(): SettingsRepository
    {
        /** @var SettingsRepository $repository */
        $repository = $this->get('models')->getRepository(Settings::class);

        return $repository;
    }
}
