<?php

namespace MilleConsorsFinanz;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\ORM\OptimisticLockException;
use Doctrine\ORM\ORMException;
use MilleConsorsFinanz\Setup\Installer;
use MilleConsorsFinanz\Setup\Updater;
use Shopware\Components\Model\ModelManager;
use Shopware\Components\Plugin;
use Shopware\Components\Plugin\Context\InstallContext;
use Shopware\Components\Plugin\Context\ActivateContext;
use Shopware\Components\Plugin\Context\DeactivateContext;
use Shopware\Components\Plugin\Context\UninstallContext;
use Shopware\Components\Plugin\Context\UpdateContext;

class MilleConsorsFinanz extends Plugin
{
    /**
     * {@inheritdoc}
     */
    public function install(InstallContext $context)
    {
        $installer = new Installer(
            $context,
            $this->container->get('shopware.plugin_payment_installer'),
            $this->container->get('models'),
            $this->container->get('dbal_connection'),
            $this->container->get('config')
        );

        $installer->install();
    }

    /**
     * {@inheritdoc}
     */
    public function update(UpdateContext $context)
    {
        $updater = new Updater(
            $context,
            $this->container->get('dbal_connection')
        );

        $updater->update();

        $context->scheduleClearCache(UninstallContext::CACHE_LIST_ALL);
    }

    /**
     * {@inheritdoc}
     */
    public function uninstall(UninstallContext $context)
    {
        $this->setPaymentMethodActive($context->getPlugin()->getPayments(), false);

        $context->scheduleClearCache(UninstallContext::CACHE_LIST_ALL);
    }

    /**
     * {@inheritdoc}
     */
    public function activate(ActivateContext $context)
    {
        $this->setPaymentMethodActive($context->getPlugin()->getPayments(), true);

        $context->scheduleClearCache(InstallContext::CACHE_LIST_ALL);
    }

    /**
     * {@inheritdoc}
     */
    public function deactivate(DeactivateContext $context)
    {
        $this->setPaymentMethodActive($context->getPlugin()->getPayments(), false);

        $context->scheduleClearCache(InstallContext::CACHE_LIST_ALL);
    }

    /**
     * @param ArrayCollection $payments
     * @param $active bool
     *
     * @throws ORMException
     * @throws OptimisticLockException
     */
    private function setPaymentMethodActive($payments, bool $active)
    {
        /** @var ModelManager $modelManager */
        $modelManager = $this->container->get('models');

        foreach ($payments as $payment) {
            $payment->setActive($active);
        }

        $modelManager->flush();
    }
}
