<?php

namespace MilleConsorsFinanz\Models\Financing;

use DateTime;
use Doctrine\ORM\Mapping as ORM;
use Exception;
use MilleConsorsFinanz\Struct\FinancingContext;
use Shopware\Components\Model\ModelEntity;

/**
 * @ORM\Entity(repositoryClass="Repository")
 * @ORM\Table(name="mille_consors_finanz_financings")
 */
class Financing extends ModelEntity
{
    /**
     * @var int
     *
     * @ORM\Column(name="id", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $id;

    /**
     * @var string
     * @ORM\Column(name="unique_id", type="string", length=255, nullable=false)
     */
    private $uniqueId;

    /**
     * @var string
     * @ORM\Column(name="transaction_id", type="string", nullable=true)
     */
    private $transactionId;

    /**
     * @var string
     * @ORM\Column(name="order_number", type="string", length=255, nullable=true)
     */
    private $orderNumber;

    /**
     * @var int
     * @ORM\Column(name="status", type="integer", nullable=true)
     */
    private $status;

    /**
     * @var string
     * @ORM\Column(name="customer_name", type="string", length=255, nullable=true)
     */
    private $customerName;

    /**
     * @var string
     * @ORM\Column(name="customer_email", type="string", length=255, nullable=true)
     */
    private $customerEmail;

    /**
     * @var float
     * @ORM\Column(name="amount", type="float", nullable=false)
     */
    private $amount;

    /**
     * @var string
     * @ORM\Column(name="billing_country_iso", type="string", nullable=false)
     */
    private $billingCountryIso;

    /**
     * @var DateTime
     * @ORM\Column(name="created_time", type="datetime", nullable=false)
     */
    private $createdTime;

    /**
     * @var DateTime
     * @ORM\Column(name="updated_time", type="datetime", nullable=true)
     */
    private $updatedTime;

    /**
     * @var FinancingContext
     */
    private $financingContext;

    public function __construct()
    {
        $this->setUniqueId($this->generateUuidV4());
        $this->setCreatedTime(new DateTime());
    }

    /**
     * @return int
     */
    public function getId(): int
    {
        return $this->id;
    }

    /**
     * @return string
     */
    public function getUniqueId(): string
    {
        return $this->uniqueId;
    }

    /**
     * @param string $uniqueId
     */
    public function setUniqueId(string $uniqueId)
    {
        $this->uniqueId = $uniqueId;
    }

    /**
     * @return string
     */
    public function getTransactionId()
    {
        return $this->transactionId;
    }

    /**
     * @param string $transactionId
     */
    public function setTransactionId(string $transactionId)
    {
        $this->transactionId = $transactionId;
    }

    /**
     * @return string
     */
    public function getOrderNumber()
    {
        return $this->orderNumber;
    }

    /**
     * @param string $orderNumber
     */
    public function setOrderNumber(string $orderNumber)
    {
        $this->orderNumber = $orderNumber;
    }

    /**
     * @return string
     */
    public function getCustomerName(): string
    {
        return $this->customerName;
    }

    /**
     * @param string $customerName
     */
    public function setCustomerName(string $customerName)
    {
        $this->customerName = $customerName;
    }

    /**
     * @return int
     */
    public function getStatus()
    {
        return $this->status;
    }

    /**
     * @param int $status
     */
    public function setStatus(int $status)
    {
        $this->status = $status;
    }

    /**
     * @return string
     */
    public function getCustomerEmail(): string
    {
        return $this->customerEmail;
    }

    /**
     * @param string $customerEmail
     */
    public function setCustomerEmail(string $customerEmail)
    {
        $this->customerEmail = $customerEmail;
    }

    /**
     * @return float
     */
    public function getAmount(): float
    {
        return $this->amount;
    }

    /**
     * @param float $amount
     */
    public function setAmount(float $amount)
    {
        $this->amount = $amount;
    }

    /**
     * @return string
     */
    public function getBillingCountryIso(): string
    {
        return $this->billingCountryIso;
    }

    /**
     * @param string $billingCountryIso
     */
    public function setBillingCountryIso(string $billingCountryIso)
    {
        $this->billingCountryIso = $billingCountryIso;

        if (!$this->financingContext) {
            $this->financingContext = new FinancingContext();
        }

        $this->financingContext->setCountry($billingCountryIso);
    }

    /**
     * @return DateTime
     */
    public function getCreatedTime(): DateTime
    {
        return $this->createdTime;
    }

    /**
     * @param DateTime $createdTime
     */
    public function setCreatedTime(DateTime $createdTime)
    {
        $this->createdTime = $createdTime;
    }

    /**
     * @return DateTime
     */
    public function getUpdatedTime()
    {
        return $this->updatedTime;
    }

    /**
     * @param DateTime $updatedTime
     */
    public function setUpdatedTime(DateTime $updatedTime)
    {
        $this->updatedTime = $updatedTime;
    }

    public function setUpdatedTimeToNow()
    {
        $this->setUpdatedTime(new DateTime());
    }

    /**
     * @return FinancingContext
     */
    public function getFinancingContext(): FinancingContext
    {
        if (!$this->financingContext) {
            $this->financingContext = new FinancingContext();
            $this->financingContext->setCountry($this->billingCountryIso);
        }

        return $this->financingContext;
    }

    /**
     * @return bool
     */
    public function hasTransactionId(): bool
    {
        return !empty($this->transactionId);
    }

    /**
     * @return bool
     */
    public function hasOrder(): bool
    {
        return !empty($this->orderNumber);
    }

    /**
     * @return string
     */
    private function generateUuidV4(): string
    {
        try {
            $data = random_bytes(16);
        } catch (Exception $e) {
            $data = openssl_random_pseudo_bytes(16);
        }

        $data[6] = chr(ord($data[6]) & 0x0f | 0x40);
        $data[8] = chr(ord($data[8]) & 0x3f | 0x80);

        return vsprintf('%s%s-%s-%s-%s-%s%s%s', str_split(bin2hex($data), 4));
    }
}
