Ext.define('Shopware.apps.MilleConsorsFinanz.view.list.Financing', {
    extend: 'Shopware.grid.Panel',
    alias:  'widget.financing-listing-grid',
    region: 'center',

    configure: function() {
        return {
            addButton: false,
            deleteButton: false,
        };
    },

    initComponent: function () {
        let me = this;

        me.columns = me.createColumns();

        me.callParent(arguments);
    },

    createColumns : function () {
        let me = this;

        return [
            {
                dataIndex: 'orderNumber',
                header: '{s name="column/orderNumber"}Bestellnummer{/s}',
                sortable: true,
                flex: 1
            },
            {
                dataIndex: 'transactionId',
                header: '{s name="column/transactionId"}Antragsnummer{/s}',
                sortable: true,
                flex: 1
            },
            {
                dataIndex: 'customerName',
                header: '{s name="column/customerName"}Kunde{/s}',
                sortable: true,
                flex: 2
            },
            {
                dataIndex: 'amount',
                header: '{s name="column/amount"}Betrag{/s}',
                renderer: me.renderAmount,
                sortable: true,
                flex: 1
            },
            {
                dataIndex: 'status',
                header: '{s name="column/status"}Aktueller Status{/s}',
                sortable: true,
                flex: 2
            },
            {
                dataIndex: 'createdTime',
                header: '{s name="column/createTime"}Antragsdatum{/s}',
                renderer: me.renderDateTime,
                sortable: true,
                width: 130
            },
            {
                dataIndex: 'updatedTime',
                header: '{s name="column/status_change_date"}Änderungsdatum{/s}',
                renderer: me.renderDateTime,
                sortable: true,
                width: 130
            },
            {
                xtype: 'actioncolumn',
                width: 60,
                items: [
                    {
                        action: 'approve',
                        iconCls:'sprite-tick',
                        tooltip: '{s name="tooltip/approve"}Versandbestätigung{/s}',
                        getClass: function(value, metadata, record) {
                            console.log('canapprove: ' + record.get('canApprove') === true ? 'y' : 'n');
                            if (!record.get('canApprove')) {
                                return 'x-hidden';
                            }
                        },
                        handler: function (view, rowIndex, colIndex, item, opts, record) {
                            me.approveFinancing(record.data.id);
                        },
                    },
                    {
                        action: 'cancel',
                        iconCls: 'sprite-cross',
                        tooltip: '{s name="tooltip/cancel"}Finanzierungsanfrage stornieren{/s}',
                        getClass: function(value, metadata, record) {
                            if (!record.get('canCancel')) {
                                return 'x-hidden';
                            }
                        },
                        handler: function (view, rowIndex, colIndex, item, opts, record) {
                            me.cancelFinancing(record.data.id);
                        },
                    }
                ]
            }
        ];
    },

    cancelFinancing: function(financingId) {
        let me = this;

        me.requestAction(
            financingId,
            '{url controller=MilleConsorsFinanz action=cancelFinancing}',
            '{s name="msgCancel"}Wollen Sie die Finanzierungsanfrage wirklich stornieren?{/s}'
        );
    },

    approveFinancing: function(financingId) {
        let me = this;

        me.requestAction(
            financingId,
            '{url controller=MilleConsorsFinanz action=approveFinancing}',
            '{s name="msgApprove"}Wollen Sie die Finanzierungsanfrage wirklich freigeben?{/s}'
        );
    },

    requestAction: function(financingId, actionUrl, confirmMsg) {
        let me = this;

        Ext.Msg.show({
            msg: confirmMsg,
            buttons: Ext.Msg.YESNO,
            icon: Ext.Msg.QUESTION,
            fn: function (response) {
                if (response !== 'yes') {
                    return;
                }

                Ext.Ajax.request({
                    url: actionUrl,
                    method: 'POST',
                    params: { 'financingId': financingId },
                    disableCaching: true,
                    success: function(response) {
                        const result = Ext.JSON.decode(response.responseText, true);

                        if (result.success === true) {
                            Shopware.Notification.createGrowlMessage('{s name="msgSuccess"}Erfolgreich{/s}');
                        } else {
                            Shopware.Notification.createGrowlMessage('{s name="msgError"}Es ist ein Fehler aufgetreten!{/s}', result.message);
                        }

                        me.getStore().reload();
                    },
                    failure: function(response) {
                        Shopware.Notification.createGrowlMessage('{s name="msgError"}{/s}', response.responseText);
                    }
                });
            }
        });
    },

    renderAmount: function (amount) {
        return Ext.util.Format.currency(amount);
    },

    renderDateTime: function (time) {
        return Ext.util.Format.date(time, 'd.m.Y H:i:s');
    }
});