// {block name="backend/mille_consors_finanz_settings/controller/main"}
Ext.define('Shopware.apps.MilleConsorsFinanzSettings.controller.Main', {
    extend: 'Enlight.app.Controller',

    init: function() {
        var me = this;

        me.createMainWindow();
        me.createComponentControl();
        me.loadSettings();

        me.callParent(arguments);
    },

    createComponentControl: function() {
        var me = this;

        me.control({
            'mille-consors-finanz-settings-toolbar': {
                'saveSettings': me.onSaveSettings
            }
        });
    },

    createMainWindow: function() {
        var me = this;

        me.window = me.getView('Window').create().show();
    },

    loadSettings: function() {
        var me = this;

        me.initRecords();

        Ext.Ajax.request({
            url: '{url controller="MilleConsorsFinanzSettings" action="loadAll"}',
            disableCaching: true,
            callback: Ext.bind(me.onLoadAjaxCallback, me)
        });
    },

    initRecords: function() {
        var me = this;

        me.recordDE = Ext.create('Shopware.apps.MilleConsorsFinanzSettings.model.Settings');
        me.recordAT = Ext.create('Shopware.apps.MilleConsorsFinanzSettings.model.Settings');

        me.recordDE.set('countryIso', 'DE');
        me.recordAT.set('countryIso', 'AT');

        me.window.tabDE.loadRecord(me.recordDE);
        me.window.tabAT.loadRecord(me.recordAT);
    },

    onLoadAjaxCallback: function(options, success, response) {
        var me = this;

        if (!success) {
            Shopware.Notification.createGrowlMessage('Consors Finanz', 'Einstellungen konnten nicht geladen werden.', me.window.title);
            return;
        }

        var data = Ext.JSON.decode(response.responseText),
            settings = data.settings;

        if (settings.DE) {
            me.recordDE = Ext.create('Shopware.apps.MilleConsorsFinanzSettings.model.Settings', settings.DE);
            me.window.tabDE.loadRecord(me.recordDE);
        }

        if (settings.AT) {
            me.recordAT = Ext.create('Shopware.apps.MilleConsorsFinanzSettings.model.Settings', settings.AT);
            me.window.tabAT.loadRecord(me.recordAT);
        }
    },

    onSaveSettings: function() {
        var me = this;

        var settings = [
            me.window.tabDE.getForm().getValues(),
            me.window.tabAT.getForm().getValues()
        ];

        me.window.setLoading('Einstellungen werden gespeichert...');

        Ext.Ajax.request({
            url: '{url controller="MilleConsorsFinanzSettings" action="save"}',
            disableCaching: true,
            params: {
                settings: JSON.stringify(settings)
            },
            callback: Ext.bind(me.onSaveAjaxCallback, me)
        });
    },

    onSaveAjaxCallback: function(options, success, response) {
        var me = this,
            responseObject = Ext.JSON.decode(response.responseText);

        me.window.setLoading(false);

        if (Ext.isDefined(responseObject) && responseObject.success) {
            Shopware.Notification.createGrowlMessage(
                'Consors Finanz',
                'Einstellungen wurden erfolgreich gespeichert.',
                me.window.title
            );

            return;
        }

        Shopware.Notification.createStickyGrowlMessage(
            {
                title: 'Consors Finanz',
                text: 'Fehler'
            },
            me.window.title
        );
    },
});
// {/block}
