// {block name="backend/mille_consors_finanz_settings/tabs/settings"}
Ext.define('Shopware.apps.MilleConsorsFinanzSettings.view.tabs.Settings', {
    extend: 'Ext.form.Panel',
    alias: 'widget.mille-consors-finanz-settings-tabs-settings',
    anchor: '100%',
    border: false,
    bodyPadding: 10,

    style: {
        background: '#ebedef'
    },

    fieldDefaults: {
        anchor: '100%',
        labelWidth: 180
    },

    initComponent: function() {
        var me = this;

        me.items = me.createItems();

        me.callParent(arguments);
    },

    /**
     * @returns { Array }
     */
    createItems: function() {
        return [
            {
                xtype: 'hidden',
                name: 'countryIso'
            }, {
                xtype: 'textfield',
                name: 'username',
                fieldLabel: 'API-Username',
                allowBlank: true
            }, {
                xtype: 'textfield',
                name: 'clientId',
                fieldLabel: 'Client-ID',
                allowBlank: true
            }, {
                xtype: 'textfield',
                name: 'vendorId',
                fieldLabel: 'Vendor-ID',
                allowBlank: true
            }, {
                xtype: 'textfield',
                name: 'vendorPassword',
                fieldLabel: 'Vendor-Passwort',
                allowBlank: true
            }, {
                xtype: 'textfield',
                name: 'hashKey',
                fieldLabel: 'Hash-Key',
                allowBlank: true
            }, {
                xtype: 'textfield',
                name: 'shopName',
                fieldLabel: 'Shop-Name',
                allowBlank: true,
                helpText: 'Bei Nutzung dieses Parameters wird Ihr Shopname als Text in der Antragstrecke angezeigt. ' +
                    'Um Kürzungen des Shopnamens („...“) zu vermeiden, übergeben Sie bitte nur ca. 1x 10 Zeichen ' +
                    '(bzw. 2x 10 Zeichen mit Leerzeichen dazwischen = Zeilenumbruch).'
            }, {
                xtype: 'mediaselectionfield',
                name: 'shopLogo',
                fieldLabel: 'Shop-Logo',
                allowBlank: true,
                helpText: 'Die Bilddatei soll das Format png oder jpg haben. Eine ideale Darstellung erreichen Sie ' +
                    'mit einem Logo im Querformat (Landscape) im Verhältnis 6:1 (Breite x Höhe) png skalierend; ' +
                    'oder ca. 150x25 px (jpg).'
            }, {
                xtype: 'textfield',
                name: 'durations',
                fieldLabel: 'Laufzeiten',
                allowBlank: true,
                helpText: 'Mit Komma getrennt, z.B. 6,12,18'
            }, {
                xtype: 'numberfield',
                name: 'defaultDuration',
                fieldLabel: 'Standarddauer',
                minValue: 1,
                allowBlank: true
            }, {
                xtype: 'textfield',
                name: 'interestRates',
                fieldLabel: 'Zinssätze',
                allowBlank: true,
                helpText: 'Zinssätze pro Laufzeitmonat mit Komma getrennt, Dezimalzahlen mit Punkt getrennt z.B. 9.0,9.0,9.5'
            }, {
                xtype: 'textfield',
                name: 'campaignVendorId',
                fieldLabel: 'Aktionszins-Vendor-ID',
                allowBlank: true
            }, {
                xtype: 'combobox',
                name: 'campaignId',
                fieldLabel: 'Aktionszins-Einstellungen',
                allowBlank: true,
                store: [
                    [0, 0],
                    [1, 1],
                    [2, 2],
                    [3, 3],
                ]
            }, {
                xtype: 'numberfield',
                name: 'campaignDuration',
                fieldLabel: 'Aktionszins-Laufzeit (Monate)',
                minValue: 0,
                allowBlank: true
            }, {
                xtype: 'numberfield',
                name: 'campaignCategoryId',
                fieldLabel: 'Aktionszins-Kategorie (ID)',
                minValue: 1,
                allowBlank: true
            }, {
                xtype: 'numberfield',
                name: 'minAmount',
                fieldLabel: 'Mindestbetrag',
                minValue: 54,
                allowBlank: true
            }, {
                xtype: 'combobox',
                name: 'financingExampleMode',
                fieldLabel: 'Ratenanzeige',
                allowBlank: true,
                store: [
                    ['lowest_installment', 'niedrigste Rate'],
                    ['lowest_zero_percent_installment', 'niedrigste 0% Rate'],
                ]
            }, {
                xtype: 'checkbox',
                name: 'createOrderBeforePayment',
                fieldLabel: 'Bestellung direkt anlegen',
                allowBlank: true
            }, {
                xtype: 'checkbox',
                name: 'liveMode',
                fieldLabel: 'Live-Modus',
                allowBlank: true
            }, {
                xtype: 'checkbox',
                name: 'logging',
                fieldLabel: 'Protokollierung',
                allowBlank: true
            }
        ];
    }
});
// {/block}
