<?php

namespace MilleConsorsFinanz\Subscriber;

use Enlight\Event\SubscriberInterface;
use Enlight_Controller_ActionEventArgs;
use Enlight_Template_Manager;
use Enlight_View_Default;

class Backend implements SubscriberInterface
{
    /**
     * @var string
     */
    private $pluginDirectory;

    /**
     * @var Enlight_Template_Manager
     */
    private $templateManager;

    /**
     * @param string $pluginDirectory
     * @param Enlight_Template_Manager $templateManager
     */
    public function __construct(string $pluginDirectory, Enlight_Template_Manager $templateManager)
    {
        $this->pluginDirectory = $pluginDirectory;
        $this->templateManager = $templateManager;
    }

    /**
     * {@inheritdoc}
     */
    public static function getSubscribedEvents(): array
    {
        return [
            'Enlight_Controller_Action_PostDispatchSecure_Backend_Index' => 'registerResources',
            'Enlight_Controller_Dispatcher_ControllerPath_Backend_MilleConsorsFinanz' => 'registerController',
            'Enlight_Controller_Dispatcher_ControllerPath_Backend_MilleConsorsFinanzSettings' => 'registerSettingsController'
        ];
    }

    /**
     * @param Enlight_Controller_ActionEventArgs $args
     */
    public function registerResources(Enlight_Controller_ActionEventArgs $args)
    {
        /** @var Enlight_View_Default $view */
        $view = $args->getSubject()->View();

        $view->addTemplateDir($this->pluginDirectory . '/Resources/views/');
        $view->extendsTemplate('backend/mille_consors_finanz/menu_icon.tpl');
    }

    /**
     * @return string
     */
    public function registerController(): string
    {
        $this->templateManager->addTemplateDir($this->pluginDirectory . '/Resources/views/');

        return $this->pluginDirectory . '/Controllers/Backend/MilleConsorsFinanz.php';
    }

    /**
     * @return string
     */
    public function registerSettingsController(): string
    {
        $this->templateManager->addTemplateDir($this->pluginDirectory . '/Resources/views/');

        return $this->pluginDirectory . '/Controllers/Backend/MilleConsorsFinanzSettings.php';
    }
}
