<?php

namespace MilleConsorsFinanz\Subscriber\Frontend;

use Enlight\Event\SubscriberInterface;
use Enlight_Controller_ActionEventArgs;
use Enlight_View_Default;
use MilleConsorsFinanz\Components\ErrorCode;
use MilleConsorsFinanz\Components\Services\CampaignService;
use MilleConsorsFinanz\Components\Settings\SettingsProvider;

class Checkout implements SubscriberInterface
{
    /**
     * @var SettingsProvider
     */
    private $settingsProvider;

    /**
     * @var CampaignService
     */
    private $campaignService;

    /**
     * @param SettingsProvider $settingsProvider
     * @param CampaignService $campaignService
     */
    public function __construct(
        SettingsProvider $settingsProvider,
        CampaignService $campaignService
    ) {
        $this->settingsProvider = $settingsProvider;
        $this->campaignService = $campaignService;
    }

    /**
     * {@inheritdoc}
     */
    public static function getSubscribedEvents(): array
    {
        return [
            'Enlight_Controller_Action_PostDispatchSecure_Frontend_Checkout' => [
                ['addMixedProductsWarning'],
                ['assignErrors']
            ]
        ];
    }

    /**
     * @param Enlight_Controller_ActionEventArgs $args
     */
    public function addMixedProductsWarning(Enlight_Controller_ActionEventArgs $args)
    {
        $controller = $args->getSubject();
        $request = $args->getRequest();

        if (!in_array($request->getActionName(), ['ajaxCart', 'cart', 'confirm'])) {
            return;
        }

        /** @var Enlight_View_Default $view */
        $view = $controller->View();
        $sBasket = $view->getAssign('sBasket');
        $sPayment = $view->getAssign('sPayment');

        if ($sPayment['name'] == 'MilleConsorsFinanz'
                && $this->settingsProvider->getMinOrderAmount() <= $sBasket['AmountNumeric']
                && $this->campaignService->containsBasketMixedArticles($sBasket['content'])) {
            $view->assign('milleConsorsFinanzErrorCode', ErrorCode::MIXED_ARTICLES_IN_CART);
        }
    }

    /**
     * @param Enlight_Controller_ActionEventArgs $args
     */
    public function assignErrors(Enlight_Controller_ActionEventArgs $args)
    {
        $controller = $args->getSubject();
        $request = $args->getRequest();

        /** @var Enlight_View_Default $view */
        $view = $controller->View();

        $errorCode = $request->getParam('mille_consors_finanz_error');

        if (!$errorCode) {
            return;
        }

        $view->assign('milleConsorsFinanzErrorCode', $errorCode);

        switch ($errorCode) {
            case ErrorCode::ORDER_AMOUNT_TOO_LOW:
                $view->assign(
                    'milleConsorsFinanzErrorMinOrderAmount',
                    $this->settingsProvider->getMinOrderAmount()
                );
                break;

            case ErrorCode::ORDER_AMOUNT_TOO_HIGH:
                $view->assign(
                    'milleConsorsFinanzErrorMaxOrderAmount',
                    $this->settingsProvider->getMaxOrderAmount()
                );
                break;
        }
    }
}
