<?php

namespace MilleConsorsFinanz\Subscriber\Frontend;

use Enlight\Event\SubscriberInterface;
use Enlight_Controller_ActionEventArgs;
use Enlight_View_Default;
use MilleConsorsFinanz\Components\Services\InstallmentsCalculator;

class Listing implements SubscriberInterface
{
    /**
     * Change to (de)activate financing examples in listing and search results.
     */
    const LISTING_FINANCING_EXAMPLES_ACTIVE = false;

    /**
     * @var InstallmentsCalculator
     */
    private $installmentsCalculator;

    /**
     * @param InstallmentsCalculator $installmentsCalculator
     */
    public function __construct(InstallmentsCalculator $installmentsCalculator)
    {
        $this->installmentsCalculator = $installmentsCalculator;
    }

    /**
     * {@inheritdoc}
     */
    public static function getSubscribedEvents(): array
    {
        return [
            'Enlight_Controller_Action_PostDispatchSecure_Frontend_Listing' => [
                ['assignFinancingExampleActive'],
                ['addFinancingExamples']
            ],
            'Enlight_Controller_Action_PostDispatchSecure_Frontend_Search' => [
                ['assignFinancingExampleActive'],
                ['addFinancingExamples']
            ]
        ];
    }

    /**
     * @param Enlight_Controller_ActionEventArgs $args
     */
    public function assignFinancingExampleActive(Enlight_Controller_ActionEventArgs $args)
    {
        /** @var Enlight_View_Default $view */
        $view = $args->getSubject()->View();

        $view->assign('milleConsorsFinanzListingFinancingExamplesActive', self::LISTING_FINANCING_EXAMPLES_ACTIVE);
    }

    /**
     * @param Enlight_Controller_ActionEventArgs $args
     */
    public function addFinancingExamples(Enlight_Controller_ActionEventArgs $args)
    {
        $controller = $args->getSubject();
        $request = $args->getRequest();

        if (!self::LISTING_FINANCING_EXAMPLES_ACTIVE
                || !in_array($request->getActionName(), ['index', 'defaultSearch'])) {
            return;
        }

        /** @var Enlight_View_Default $view */
        $view = $controller->View();

        $sArticles = $view->getAssign('sArticles');

        if ($request->getControllerName() == 'search') {
            $sSearchResults = $view->getAssign('sSearchResults');
            $sArticles = $sSearchResults['sArticles'] ?? null;
        }

        if (!$sArticles) {
            return;
        }

        foreach ($sArticles as &$sArticle) {
            $financingExample = $this->installmentsCalculator->getFinancingExample(
                $sArticle['articleID'],
                $sArticle['price_numeric']
            );

            if ($financingExample) {
                $sArticle['milleConsorsFinanzFinancingExample'] = $financingExample->toArray();
            }
        }

        if ($request->getControllerName() == 'search') {
            $sSearchResults['sArticles'] = $sArticles;
            $view->assign('sSearchResults', $sSearchResults);
        } else {
            $view->assign('sArticles', $sArticles);
        }
    }
}
