<?php
namespace MilleConsorsFinanzRK\Bootstrap;

use Shopware\Bundle\AttributeBundle\Service\CrudService;
use Shopware\Bundle\AttributeBundle\Service\TypeMapping;
use Shopware\Components\Model\ModelManager;

class Attributes
{
    /**
     * @var CrudService
     */
    private $crudService;

    /**
     * @var ModelManager
     */
    private $modelManager;
    
    private $attributeTables = [
        's_user_attributes',
        's_order_attributes'
    ];
    
    /**
     * @param CrudService  $crudService
     * @param ModelManager $modelManager
     */
    public function __construct(CrudService $crudService, ModelManager $modelManager)
    {
        $this->crudService = $crudService;
        $this->modelManager = $modelManager;
    }
    
    public function install()
    {
        $this->crudService->update(
            's_user_attributes',
            'consors_finanz_userreference',
            TypeMapping::TYPE_STRING,
            [
                'displayInBackend' => true,
                'label' => 'User reference',
                'translatable' => true,
            ]
        );

        $this->crudService->update(
            's_order_attributes',
            'consors_finanz_is_order_booked',
            TypeMapping::TYPE_BOOLEAN,
            [
                'displayInBackend' => false,
            ]
        );

        $this->crudService->update(
            's_order_attributes',
            'consors_finanz_is_order_cancelled',
            TypeMapping::TYPE_BOOLEAN,
            [
                'displayInBackend' => false,
            ]
        );

        $this->crudService->update(
            's_order_attributes',
            'consors_finanz_order_credit_numbers',
            TypeMapping::TYPE_STRING,
            [
                'displayInBackend' => false,
            ]
        );

        // Version 1.0.3
        $this->crudService->update(
            's_order_attributes',
            'consors_finanz_customer_number',
            TypeMapping::TYPE_STRING,
            [
                'label' => 'Abweichende Kundennummer',
                'displayInBackend' => true,
            ]
        );

        $this->crudService->update(
            's_order_attributes',
            'consors_finanz_order_invoice_number',
            TypeMapping::TYPE_STRING,
            [
                'label' => 'Belegnummer',
                'displayInBackend' => true,
            ]
        );

        $this->crudService->update(
            's_order_attributes',
            'consors_finanz_order_date',
            TypeMapping::TYPE_STRING,
            [
                'label' => 'Datum',
                'displayInBackend' => true,
            ]
        );

        $this->crudService->update(
            's_order_attributes',
            'consors_finanz_order_due_date',
            TypeMapping::TYPE_STRING,
            [
                'label' => 'Fälligkeitsdatum',
                'displayInBackend' => true,
            ]
        );

        $this->crudService->update(
            's_order_attributes',
            'consors_finanz_order_amount',
            TypeMapping::TYPE_STRING,
            [
                'label' => 'Betrag',
                'displayInBackend' => true,
            ]
        );

        $this->crudService->update(
            's_order_attributes',
            'consors_finanz_order_invoice_type',
            TypeMapping::TYPE_STRING,
            [
                'label' => 'Belegtyp',
                'displayInBackend' => true,
            ]
        );

        $this->crudService->update(
            's_order_attributes',
            'consors_finanz_order_invoice_reference',
            TypeMapping::TYPE_STRING,
            [
                'label' => 'Belegreferenz',
                'displayInBackend' => true,
            ]
        );

        $this->crudService->update(
            's_order_attributes',
            'consors_finanz_order_change_flag',
            TypeMapping::TYPE_BOOLEAN,
            [
                'label' => 'Changeflag',
                'displayInBackend' => true,
            ]
        );

        $this->modelManager->generateAttributeModels($this->attributeTables);
    }
    
    public function uninstall()
    {
        if ($this->crudService->get('s_user_attributes', 'consors_finanz_userreference')) {
            $this->crudService->delete('s_user_attributes', 'consors_finanz_userreference');
        }
        if ($this->crudService->get('s_order_attributes', 'consors_finanz_is_order_booked')) {
            $this->crudService->delete('s_order_attributes', 'consors_finanz_is_order_booked');
        }
        if ($this->crudService->get('s_order_attributes', 'consors_finanz_is_order_cancelled')) {
            $this->crudService->delete('s_order_attributes', 'consors_finanz_is_order_cancelled');
        }
        if ($this->crudService->get('s_order_attributes', 'consors_finanz_order_credit_numbers')) {
            $this->crudService->delete('s_order_attributes', 'consors_finanz_order_credit_numbers');
        }

        // Version 1.0.3

        if ($this->crudService->get('s_order_attributes', 'consors_finanz_customer_number')) {
            $this->crudService->delete('s_order_attributes', 'consors_finanz_customer_number');
        }
        if ($this->crudService->get('s_order_attributes', 'consors_finanz_order_invoice_number')) {
            $this->crudService->delete('s_order_attributes', 'consors_finanz_order_invoice_number');
        }
        if ($this->crudService->get('s_order_attributes', 'consors_finanz_order_date')) {
            $this->crudService->delete('s_order_attributes', 'consors_finanz_order_date');
        }
        if ($this->crudService->get('s_order_attributes', 'consors_finanz_order_due_date')) {
            $this->crudService->delete('s_order_attributes', 'consors_finanz_order_due_date');
        }
        if ($this->crudService->get('s_order_attributes', 'consors_finanz_order_amount')) {
            $this->crudService->delete('s_order_attributes', 'consors_finanz_order_amount');
        }
        if ($this->crudService->get('s_order_attributes', 'consors_finanz_order_invoice_type')) {
            $this->crudService->delete('s_order_attributes', 'consors_finanz_order_invoice_type');
        }
        if ($this->crudService->get('s_order_attributes', 'consors_finanz_order_invoice_reference')) {
            $this->crudService->delete('s_order_attributes', 'consors_finanz_order_invoice_reference');
        }
        if ($this->crudService->get('s_order_attributes', 'consors_finanz_order_change_flag')) {
            $this->crudService->delete('s_order_attributes', 'consors_finanz_order_change_flag');
        }

        $this->modelManager->generateAttributeModels($this->attributeTables);
    }
}
