<?php
namespace MilleConsorsFinanzRK\Bootstrap;

use Doctrine\DBAL\Connection;
use Shopware\Components\Model\ModelManager;
use Shopware\Models\Payment\Payment;

class Database
{
    /**
     * @var ModelManager
     */
    private $modelManager;

    /**
     * @var Connection
     */
    private $dbalConnection;

    private $pluginPath;

    const INVOICE_PAYMENT_METHOD_NAME = 'MilleConsorsFinanzRKInvoice';

    const DEBIT_PAYMENT_METHOD_NAME = 'MilleConsorsFinanzRKDebit';

    private $paymentMethodData = [
        [
            'name' => self::INVOICE_PAYMENT_METHOD_NAME,
            'position' => -101,
            'description' => 'Kauf auf Rechnung by Consors Finanz',
            'additionalDescription' => 'Bei Auswahl der Zahlungsart „Kauf auf Rechnung“ überweisen Sie den Kaufpreis erst 30 Tage nach Erhalt der Ware.',
            'action' => 'ConsorsFinanzInvoice',
            'template' => 'consors_finanz_invoice.tpl',
            'class' => 'ConsorsFinanzInvoice',
        ],
        [
            'name' => self::DEBIT_PAYMENT_METHOD_NAME,
            'position' => -100,
            'description' => 'Kauf per Lastschrift by Consors Finanz',
            'additionalDescription' => 'Bei Auswahl der Zahlungsart „Kauf per Lastschrift“ zieht die Consors Finanz den Kaufpreis erst 30 Tage nach Erhalt der Ware ein.',
            'action' => 'ConsorsFinanzDebit',
            'template' => 'consors_finanz_debit.tpl',
            'class' => 'ConsorsFinanzDebit',
        ]
    ];

    /**
     * Database constructor.
     * @param ModelManager $modelManager
     * @param $pluginPath
     */
    public function __construct(ModelManager $modelManager, $pluginPath) {
        $this->pluginPath = $pluginPath;
        $this->modelManager = $modelManager;
        $this->dbalConnection = $modelManager->getConnection();
    }
    
    public function install()
    {
        $this->createPaymentMethods();
    }
    
    public function uninstall()
    {
        $this->deactivatePaymentMethods();
    }

    private function createPaymentMethods()
    {
        foreach ($this->paymentMethodData as $paymentMethodDatum) {
            $payment = $this->modelManager->getRepository(Payment::class)->findOneBy([
                'name' => $paymentMethodDatum['name'],
            ]);

            if (!$payment) {
                //If the payment does already exist, we don't need to add it again.
                $payment = new Payment();
            }

            $payment->setActive(true);
            $payment->setPosition($paymentMethodDatum['position']);
            $payment->setName($paymentMethodDatum['name']);
            $payment->setTemplate($paymentMethodDatum['template']);
            $payment->setClass($paymentMethodDatum['class']);
            $payment->setDescription($paymentMethodDatum['description']);
            $payment->setAdditionalDescription($this->getConsorsFinanzLogo() . $paymentMethodDatum['additionalDescription']);
            $payment->setAction($paymentMethodDatum['action']);
            $this->modelManager->persist($payment);
        }

        $this->modelManager->flush();
    }

    public function deactivatePaymentMethods()
    {
        foreach ($this->paymentMethodData as $paymentMethodDatum) {
            $paymentMethod = $this->modelManager->getRepository(Payment::class)->findOneBy(['name' => $paymentMethodDatum['name']]);
            if ($paymentMethod) {
                $paymentMethod->setActive(false);
                $this->modelManager->persist($paymentMethod);
            }
        }
        $this->modelManager->flush();
    }

    /**
     * @return string
     */
    private function getConsorsFinanzLogo()
    {
        return '<!-- Consors Finanz Logo -->'
            . '<a onclick="window.open(this.href, \'olcwhatispaypal\',\'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=yes, resizable=yes, width=400, height=500\'); return false;"'
            . ' href="https://www.consorsfinanz.de" target="_blank">'
            . '<img style="width: 18%; margin-top: 5px;" src="{link file=\'frontend/_public/src/img/consors-finanz.png\' fullPath}" alt="Consors Finanz Logo">'
            . '</a><br><!-- Consors Finanz Logo -->';
    }
}
