<?php
namespace MilleConsorsFinanzRK\Bootstrap;

use Doctrine\DBAL\Connection;
use Shopware\Components\Model\ModelManager;
use Shopware\Models\Menu\Menu;
use Shopware\Models\Plugin\Plugin;

class Updater
{
    /**
     * @var Connection
     */
    private $connection;
    /**
     * @var ModelManager
     */
    private $modelManager;

    const PLUGIN_NAME = 'MilleConsorsFinanzRK';
    /**
     * @var Attributes
     */
    private $attribute;

    /**
     * @param ModelManager $modelManager
     * @param Attributes   $attribute
     */
    public function __construct(ModelManager $modelManager, Attributes $attribute)
    {
        $this->modelManager = $modelManager;
        $this->connection = $modelManager->getConnection();
        $this->attribute = $attribute;
    }

    /**
     * @param string $oldVersion
     */
    public function update($oldVersion)
    {
        if (version_compare($oldVersion, '2.0.4', '<=')) {
            $this->update204();
        }

        if (version_compare($oldVersion, '1.0.5', '<=')) {
            $this->update105();
        }

        if (version_compare($oldVersion, '1.0.4', '<=')) {
            $this->update104();
        }

        if (version_compare($oldVersion, '1.0.3', '<=')) {
            $this->update103();
        }

        if (version_compare($oldVersion, '1.0.1', '<=')) {
            $this->update101();
        }
    }

    private function update204()
    {
        $deShopId = $this->getLocaleShopId('de_DE');

        if (0 != $deShopId) {
            $this->connection->createQueryBuilder()
                ->update('s_core_snippets')
                ->set('value', ':value')
                ->where('namespace LIKE :namespace')
                ->andWhere('name = :name')
                ->andWhere('shopID = :shopID')
                ->setParameter('value', 'Derzeit können wir Ihnen die gewünschte Zahlart nicht anbieten. Wählen Sie bitte eine alternative Zahlungsart.')
                ->setParameter('namespace', 'backend/consors_finanz/checkout/messages')
                ->setParameter('name', 'error/credit_rating_not_sufficient')
                ->setParameter('shopID', $deShopId)
                ->execute();
        }
    }

    private function update105()
    {
        $this->attribute->install();

        /** @var Plugin $consorsPlugin */
        $consorsPlugin = $this->modelManager->getRepository(Plugin::class)
            ->findOneBy(['name' => self::PLUGIN_NAME]);

        if (!$consorsPlugin) {
            return;
        }

        /** @var Menu $menuOrders */
        $menuOrders = $this->modelManager->getRepository(Menu::class)
            ->findOneBy(
                [
                    'plugin' => $consorsPlugin,
                    'label' => 'MilleConsorsFinanzRKOrders',
                    'class' => 'sprite--consors-finanz',
                ]
            );

        if ($menuOrders) {
            $menuOrders->setController('ConsorsFinanzRK');
            $this->modelManager->persist($menuOrders);
        }

        $this->modelManager->flush();
    }

    private function update104()
    {
        $this->attribute->install();
    }

    private function update103()
    {
        $this->attribute->install();
    }

    private function update101()
    {
        /** @var Plugin $consorsPlugin */
        $consorsPlugin = $this->modelManager->getRepository(Plugin::class)
            ->findOneBy(['name' => self::PLUGIN_NAME]);

        if (!$consorsPlugin) {
            return;
        }

        /** @var Menu $menu */
        $menu = $this->modelManager->getRepository(Menu::class)
            ->findOneBy(
                [
                    'plugin' => $consorsPlugin,
                    'label' => 'ConsorsFinanz',
                    'class' => 'sprite--consors-finanz',
                ]
            );

        if ($menu) {
            $menu->setLabel('ConsorsFinanzRK');
            $this->modelManager->persist($menu);
        }

        /** @var Menu $menuOrders */
        $menuOrders = $this->modelManager->getRepository(Menu::class)
            ->findOneBy(
                [
                    'plugin' => $consorsPlugin,
                    'label' => 'MilleConsorsFinanzRKOrders',
                    'class' => 'sprite--consors-finanz',
                ]
            );

        if ($menuOrders) {
            $menuOrders->setController('ConsorsFinanzRK');
            $this->modelManager->persist($menuOrders);
        }

        $this->modelManager->flush();
    }

    private function getLocaleShopId($locale = 'de_DE')
    {
        return (int)$this->connection->createQueryBuilder()
            ->select('shop.id')
            ->from('s_core_shops', 'shop')
            ->leftJoin('shop', 's_core_locales', 'locales', 'shop.locale_id = locales.id')
            ->where('locales.locale = :locale')
            ->setParameter('locale', $locale)
            ->execute()
            ->fetchColumn();
    }
}
