<?php
namespace MilleConsorsFinanzRK\Components;

use Shopware\Components\DependencyInjection\Container as DIContainer;
use Shopware\Components\Model\ModelManager;
use Shopware\Components\Plugin\ConfigReader;
use Shopware\Models\Payment\Payment;
use Shopware_Components_Config;
use Shopware_Components_Snippet_Manager;
use MilleConsorsFinanzRK\Bootstrap\Database;

class Configuration
{
    /**
     * Plugin namespace
     *
     * @var Shopware_Components_Config
     */
    protected $namespace;
    
    /**
     * @var ConfigReader
     */
    private $configReader;
    
    /**
     * @var ModelManager
     */
    private $modelManager;
    
    /**
     * @var Shopware_Components_Snippet_Manager
     */
    private $snippetManager;
    /**
     * @var DIContainer
     */
    private $container;

    /**
     * Configuration constructor.
     * @param                                      $namespace
     * @param ConfigReader                         $configReader
     * @param ModelManager                         $modelManager
     * @param Shopware_Components_Snippet_Manager  $snippetManager
     * @param DIContainer                          $container
     */
    public function __construct(
        $namespace,
        ConfigReader $configReader,
        ModelManager $modelManager,
        Shopware_Components_Snippet_Manager $snippetManager,
        DIContainer $container
    ) {
        $this->configReader = $configReader;
        $this->modelManager = $modelManager;
        $this->namespace = $namespace;
        $this->snippetManager = $snippetManager;
        $this->container = $container;
    }

    public function isActive()
    {
        return (bool) $this->getPluginConfig('MilleConsorsFinanzRKActivate');
    }

    /**
     * @param $shop
     * @return array
     * @throws \Exception
     */
    public function getPluginData($shop = null)
    {
       return [
           'isActive' => (bool) $this->getPluginConfig('MilleConsorsFinanzRKActivate', $shop),
           'isSandboxActive' => (bool) ($this->getPluginConfig('MilleConsorsFinanzRKMode', $shop) == 'T'),
           'invoicePaymentMethodId' => $this->getPaymentMethodId(Database::INVOICE_PAYMENT_METHOD_NAME),
           'debitPaymentMethodId' => $this->getPaymentMethodId(Database::DEBIT_PAYMENT_METHOD_NAME),
           'isInvoiceActive' => $this->isPaymentActive(Database::INVOICE_PAYMENT_METHOD_NAME),
           'isDebitActive' => $this->isPaymentActive(Database::DEBIT_PAYMENT_METHOD_NAME),
           'codeNumber' => $this->getPluginConfig('MilleConsorsFinanzRKCodeNumber', $shop),
           'password' => $this->getPluginConfig('MilleConsorsFinanzRKPassword', $shop),
           'mode' => $this->getPluginConfig('MilleConsorsFinanzRKMode', $shop),
           'system' => $this->getPluginConfig('MilleConsorsFinanzRKManagementSystem', $shop),
           'completedOrderStatus' => $this->getPluginConfig('MilleConsorsFinanzRKOrderStatus', $shop),
           'completedOrderState' => $this->getPluginConfig('MilleConsorsFinanzRKOrderState', $shop),
           'maxBasketValue' => $this->getPluginConfig('MilleConsorsFinanzRKMaxBasketValue', $shop),
       ];
    }

    private function isPaymentActive($name)
    {
        $payment = $this->modelManager->getRepository(Payment::class)
            ->findOneBy(['name' => $name]);

        if ($payment && $payment instanceof Payment) {
            return (bool)$payment->getActive();
        }

        return false;
    }

    private function getPaymentMethodId($name)
    {
        $payment = $this->modelManager->getRepository(Payment::class)
            ->findOneBy(['name' => $name]);

        if ($payment && $payment instanceof Payment) {
            return $payment->getId();
        }

        return 0;
    }

    /**
     * @param $key
     * @param $shop
     * @return bool|mixed
     * @throws \Exception
     */
    public function getPluginConfig($key, $shop = null)
    {
        if ('' === $this->namespace) {
            throw new \Exception('Plugin namespace does not exist.');
        }

        $config = $shop
            ? $this->configReader->getByPluginName($this->namespace, $shop)
            : $this->configReader->getByPluginName($this->namespace, $this->getShop());
        return isset($config[$key]) ? $config[$key] : false;
    }

    /**
     * @param        $path
     * @param        $name
     * @param string $defaultValue
     * @return mixed|null
     */
    public function getSnippet($path, $name, $defaultValue = '')
    {
        return $this->snippetManager->getNamespace($path)->get($name, $defaultValue);
    }

    public function getShop()
    {
        if ($this->container->has('shop')) {
            return $this->container->get('shop');
        }

        return null;
    }
}
