<?php
namespace MilleConsorsFinanzRK\Components\Consors\Request;

class BelegeRequest
{
    /**
     * @var string $kundennummer
     */
    protected $kundennummer;

    /**
     * @var string $belegtyp
     */
    protected $belegtyp;

    /**
     * @var string $belegnummer
     */
    protected $belegnummer;

    /**
     * @var string $belegdatum
     */
    protected $belegdatum;

    /**
     * @var string $belegreferenz
     */
    protected $belegreferenz;

    /**
     * @var string $faellig
     */
    protected $faellig;

    /**
     * @var double $betrag
     */
    protected $betrag;

    /**
     * @var double $betragNetto
     */
    protected $betragNetto;

    /**
     * @var string $waehrung
     */
    protected $waehrung;

    /**
     * @var string $zahlart
     */
    protected $zahlart;

    /**
     * @var string $betrag
     */
    protected $rgbezahlt;

    /**
     * @var string $belegtext
     */
    protected $belegtext;

    /**
     * @var BelegPositionRequest[] $belegpositionen
     */
    protected $belegpositionen;

    /**
     * @var PersonRequest $leferperson
     */
    protected $leferperson;

    /**
     * @var MainAddressRequest $lieferanschrift
     */
    protected $lieferanschrift;

    /**
     * HeaderRequest constructor.
     * @param $beleg
     */
    public function __construct($beleg)
    {
        $this->setKundennummer($beleg['kundennummer']);
        $this->setBelegtyp($beleg['belegtyp']);
        $this->setBelegnummer($beleg['belegnummer']);

        $this->setBelegdatum($beleg['belegdatum']);

        if (isset($beleg['belegreferenz'])) {
            $this->setBelegreferenz($beleg['belegreferenz']);
        }

        $this->setFaellig($beleg['faellig']);
        $this->setBetrag($beleg['betrag']);
        $this->setBetragNetto($beleg['betrag_netto']);
        $this->setWaehrung($beleg['waehrung']);
        $this->setZahlart($beleg['zahlart']);
        $this->setRgbezahlt($beleg['rgbezahlt']);

        if (isset($beleg['belegtext'])) {
            $this->setBelegtext($beleg['belegtext']);
        }

        $this->managePositions($beleg['belegpositionen']);
    }

    /**
     * @return string
     */
    public function getKundennummer()
    {
        return $this->kundennummer;
    }

    /**
     * @param string $kundennummer
     */
    public function setKundennummer($kundennummer)
    {
        $this->kundennummer = $kundennummer;
    }

    /**
     * @return string
     */
    public function getBelegtyp()
    {
        return $this->belegtyp;
    }

    /**
     * @param string $belegtyp
     */
    public function setBelegtyp($belegtyp)
    {
        $this->belegtyp = $belegtyp;
    }

    /**
     * @return string
     */
    public function getBelegnummer()
    {
        return $this->belegnummer;
    }

    /**
     * @param string $belegnummer
     */
    public function setBelegnummer($belegnummer)
    {
        $this->belegnummer = $belegnummer;
    }

    /**
     * @return string
     */
    public function getBelegdatum()
    {
        return $this->belegdatum;
    }

    /**
     * @param string $belegdatum
     */
    public function setBelegdatum($belegdatum)
    {
        $this->belegdatum = $belegdatum;
    }

    /**
     * @param string $belegreferenz
     */
    public function setBelegreferenz($belegreferenz)
    {
        $this->belegreferenz = $belegreferenz;
    }

    /**
     * @return string
     */
    public function getBelegreferenz()
    {
        return $this->belegreferenz;
    }

    /**
     * @return string
     */
    public function getFaellig()
    {
        return $this->faellig;
    }

    /**
     * @param string $faellig
     */
    public function setFaellig($faellig)
    {
        $this->faellig = $faellig;
    }

    /**
     * @return string
     */
    public function getBetrag()
    {
        return $this->betrag;
    }

    /**
     * @return double
     */
    public function getBetragNetto()
    {
        return $this->betragNetto;
    }

    /**
     * @param float $betragNetto
     */
    public function setBetragNetto($betragNetto)
    {
        $this->betragNetto = $betragNetto;
    }

    /**
     * @param string $waehrung
     */
    public function setWaehrung($waehrung)
    {
        $this->waehrung = $waehrung;
    }

    /**
     * @return string
     */
    public function getWaehrung()
    {
        return $this->waehrung;
    }

    /**
     * @return string
     */
    public function getZahlart()
    {
        return $this->zahlart;
    }

    /**
     * @param string $zahlart
     */
    public function setZahlart($zahlart)
    {
        $this->zahlart = $zahlart;
    }

    /**
     * @return string
     */
    public function getRgbezahlt()
    {
        return $this->rgbezahlt;
    }

    /**
     * @param string $rgbezahlt
     */
    public function setRgbezahlt($rgbezahlt)
    {
        $this->rgbezahlt = $rgbezahlt;
    }

    /**
     * @return string
     */
    public function getBelegtext()
    {
        return $this->belegtext;
    }

    /**
     * @param string $belegtext
     */
    public function setBelegtext($belegtext)
    {
        $this->belegtext = $belegtext;
    }

    /**
     * @return PersonRequest
     */
    public function getLeferperson(): PersonRequest
    {
        return $this->leferperson;
    }

    /**
     * @param PersonRequest $leferperson
     */
    public function setLeferperson(PersonRequest $leferperson)
    {
        $this->leferperson = $leferperson;
    }

    /**
     * @return MainAddressRequest
     */
    public function getLieferanschrift(): MainAddressRequest
    {
        return $this->lieferanschrift;
    }

    /**
     * @param MainAddressRequest $lieferanschrift
     */
    public function setLieferanschrift(MainAddressRequest $lieferanschrift)
    {
        $this->lieferanschrift = $lieferanschrift;
    }

    /**
     * @return BelegPositionRequest[]
     */
    public function getBelegpositionen()
    {
        return $this->belegpositionen;
    }

    /**
     * @param BelegPositionRequest[] $belegpositionen
     */
    public function setBelegpositionen($belegpositionen)
    {
        $this->belegpositionen = $belegpositionen;
    }

    /**
     * @param float $betrag
     */
    public function setBetrag($betrag)
    {
        $this->betrag = $betrag;
    }

    private function managePositions($positions)
    {
        $array = [];
        foreach ($positions as $position) {
            $array[] = new BelegPositionRequest($position);
        }

        $this->setBelegpositionen($array);
    }
}