<?php
namespace MilleConsorsFinanzRK\Components\Consors\Services;

use MilleConsorsFinanzRK\Components\Consors\Api\ConsorsSoapClientFault;
use MilleConsorsFinanzRK\Components\Consors\Request\BoniCheck2Request;
use MilleConsorsFinanzRK\Components\Consors\Response\BoniCheck2Response;
use MilleConsorsFinanzRK\Components\SettingsTable;

class BoniCheckService extends AbstractService
{
    const ACCOUNT_TYPE = 'ESHOPKONTONUM';

    /**
     * @param        $sOrderVariables
     * @param string $anfrageart
     * @param        $shopId
     * @return BoniCheck2Response
     * @throws ConsorsSoapClientFault
     */
    public function checkBoni($sOrderVariables, string $anfrageart, $shopId)
    {
        if (empty($this->orderData)) {
            $this->orderData = $sOrderVariables;
            $this->orderData['sBasket'] = $this->getBasket();
        }

        $request = $this->getRequest($anfrageart, $shopId);

        /** @var BoniCheck2Response $response */
        $response = $this->consorsApi->boniCheck2($request);
        return $response;
    }

    /**
     * @param $anfrageart
     * @param $shopId
     * @return BoniCheck2Request
     */
    private function getRequest($anfrageart, $shopId)
    {
        $params = array_merge(
            $this->getDefaultParams($anfrageart, $shopId),
            $this->getBoniParams($anfrageart)
        );

        return new BoniCheck2Request($params);
    }

    /**
     * @param string $anfrageart
     * @return array
     */
    private function getBoniParams($anfrageart = 'ZG')
    {
        $userData = $this->orderData['sUserData'];
        $user = $userData['additional']['user'];
        $billingAddress = $userData['billingaddress'];
        $shippingaddress = $userData['shippingaddress'];

        return [
            'kontotype' => self::ACCOUNT_TYPE,
            'kontonummer' => $user['customernumber'],
            'person' => $this->getPerson($user, $billingAddress, $anfrageart),
            'lieferperson' => $this->getPerson($user, $shippingaddress, $anfrageart, true),
            'lieferanschrift' => [
                'adresse' => $this->getAddress($shippingaddress),
                'zusatz' => $shippingaddress['additionalAddressLine1']
            ],
        ];
    }

    private function getPerson($user, $address, $anfrageart = 'ZG', $liefer = false)
    {
        $person = [
                'salutation' => $this->translateSalutation($address['salutation']),
                'vorname' => ($liefer === true) ? $address['firstname'] : $user['firstname'],
                'name' => ($liefer === true) ? $address['lastname'] : $user['lastname'],
                'geburtsdatum' => $user['birthday'],
                'hauptanschrift' => [
                    'adresse' => $this->getAddress($address),
                    'zusatz' => $address['additionalAddressLine1']
                ],
                'kontakte' => [
                    [
                        'typ' => 'mobil',
                        'kontakt' => $address['phone']
                    ],
                    [
                        'typ' => 'email',
                        'kontakt' => $user['email']
                    ],
                ],
                'rechtsform' => '',
                'handelsregisternummer' => '',
                'amtsgericht' => '',
        ];

        if (SettingsTable::REQUEST_TYPE_DEBIT == $anfrageart) {
            $bankData = $this->getUserBankData($user['id']);
            if (!empty($bankData)) {
                $person = array_merge(
                    $person,
                    ['bankverbindungen' => $bankData]
                );
            }
        }

        return $person;
    }
}