<?php
namespace MilleConsorsFinanzRK\Components\Consors\Services;

use MilleConsorsFinanzRK\Bootstrap\Database;
use MilleConsorsFinanzRK\Components\Consors\Api\ConsorsSoapClientFault;
use MilleConsorsFinanzRK\Components\Consors\Response\Change2Response;

class ChangeManagementSystemService extends ChangeService
{
    /**
     * @param array $order
     * @param       $changetyp
     * @param       $shopId
     * @param bool  $isGutschrift
     * @return Change2Response
     * @throws ConsorsSoapClientFault
     */
    public function change(array $order, $changetyp, $shopId, $isGutschrift = false)
    {
        $request = $this->getParams($order, $changetyp, $shopId, $isGutschrift);
//        $this->dumb($request);

        /** @var Change2Response $response */
        $response = $this->consorsApi->changeOrder($request);
        return $response;
    }

    /**
     * @param array $order
     * @param bool  $isGutschrift
     * @return \string[][]
     */
    protected function getChangeParams(array $order, $isGutschrift = false)
    {
        $attribute = $order['attribute'];
        $belege = $this->getBelege($order, $isGutschrift);
        $debitor = $this->getDebitor($order);

        return [
            'referenzen' => [
                'referenztyp' => 'bestellnummer',
                'referenzwert' => $attribute['consorsFinanzOrderInvoiceReference'] ?: $order['number'] ,
            ],
            'debitor' => $debitor,
            'belege' => $belege,
        ];
    }

    protected function getBelege($orderData, $isGutschrift = false)
    {
        $payment = $orderData['payment'];
        $attribute = $orderData['attribute'];
        $belegreferenz = $attribute['consorsFinanzOrderInvoiceReference'];

        $tax = round($this->getTaxFromGrossAndNet($orderData['invoiceAmount'], $orderData['invoiceAmountNet']));

        $betrag = round(str_replace(',', '.', $attribute['consorsFinanzOrderAmount']) * 100, 2);
        $betragNetto = round($this->getNetto(str_replace(',', '.', $attribute['consorsFinanzOrderAmount']), $tax) * 100, 2);

        $beleg = [
            'kundennummer' => $attribute['consorsFinanzCustomerNumber'],
            'belegtyp' => $attribute['consorsFinanzOrderInvoiceType'],
            'belegnummer' => $attribute['consorsFinanzOrderInvoiceNumber'],
            'belegdatum' => $this->convertDate($attribute['consorsFinanzOrderDate']),
            'faellig' => $this->convertDate($attribute['consorsFinanzOrderDueDate']),
            'waehrung' => $orderData['currency'],
//            'betrag' => $isGutschrift ? $betrag * -1 : $betrag,
            'betrag' => $betrag,
//            'betrag_netto' => $isGutschrift ? $betragNetto * -1 : $betragNetto,
            'betrag_netto' => $betragNetto,
            'zahlart' => (Database::DEBIT_PAYMENT_METHOD_NAME == $payment['name']) ? 'LA' : 'UEB',
            'rgbezahlt' => 'NEIN',
            'belegpositionen' => $this->getBelegPositions($orderData, true),
        ];

        if ($isGutschrift) {
            $beleg['belegreferenz'] = $belegreferenz;
            $beleg['belegtext'] = 'Gutschrift zu Rechnung ' . $belegreferenz . ' vom ' . $attribute['consorsFinanzOrderDate'];
        } else {
            $beleg['belegtext'] = 'Rechnung zur Bestellung ' . $orderData['number'] . ' vom ' . $attribute['consorsFinanzOrderDate'];
        }

        return $beleg;
    }

    protected function getDebitor($orderData)
    {
        $attribute = $orderData['attribute'];
        $billing = $orderData['billing'];
        $customer = $orderData['customer'];
        return [
            'kundennummer' => $attribute['consorsFinanzCustomerNumber'] ? : $customer['number'],
            'bezeichnung' => $customer['firstname'] . ' ' . $customer['lastname'],
            'person' => $this->getPerson($customer, $billing)
        ];
    }
}