<?php
namespace MilleConsorsFinanzRK\Components\Consors\Services;

use MilleConsorsFinanzRK\Components\Consors\Api\ConsorsSoapClientFault;
use MilleConsorsFinanzRK\Components\Consors\Request\OrderStornoRequest;
use MilleConsorsFinanzRK\Components\Consors\Response\OrderStornoResponse;

class OrderStornoService extends AbstractService
{
    /**
     * @param        $ordernumber
     * @param        $anfrageart
     * @param        $shopId
     * @param string $referenzwert
     * @return OrderStornoResponse
     * @throws ConsorsSoapClientFault
     */
    public function cancel($ordernumber, $anfrageart, $shopId, $referenzwert = '')
    {
        $request = $this->getParams($ordernumber, $anfrageart, $shopId, $referenzwert);

//        $this->dumb($request);

        /** @var OrderStornoResponse $response */
        $response = $this->consorsApi->cancelOrder($request);
        return $response;
    }

    /**
     * @param        $ordernumber
     * @param        $anfrageart
     * @param        $shopId
     * @param string $referenzwert
     * @return OrderStornoRequest
     */
    private function getParams($ordernumber, $anfrageart, $shopId, $referenzwert = '')
    {
        $params = array_merge(
            $this->getDefaultParams($anfrageart, $shopId),
            $this->getStornoParams($ordernumber, $referenzwert)
        );

        return new OrderStornoRequest($params);
    }

    /**
     * @param $changetyp
     * @param $shopId
     * @return array
     */
    protected function getDefaultParams($changetyp, $shopId)
    {
        return [
            'config' => $this->getConfigByShopId($shopId),
            'anfrageart' => $changetyp,
            'bestellwert' => 0,
        ];
    }

    /**
     * @param        $ordernumber
     * @param string $referenzwert
     * @return \string[][]
     */
    private function getStornoParams($ordernumber, $referenzwert = '')
    {
        return [
            'referenzen' => [
                'referenztyp' => 'bestellnummer',
                'referenzwert' => $referenzwert ?: $ordernumber,
            ]
        ];
    }
}