<?php
namespace MilleConsorsFinanzRK\Components\PaymentMethods;

use Shopware\Models\Customer\Address;
use Shopware\Models\Customer\Customer;
use ShopwarePlugin\PaymentMethods\Components\GenericPaymentMethod;

abstract class AbstractPaymentMethod extends GenericPaymentMethod
{
    protected $pluginData;

    public function __construct()
    {
        $shop = Shopware()->Shop();
        $configuration = Shopware()->Container()->get('shopware.plugin.cached_config_reader')->getByPluginName('MilleConsorsFinanzRK', $shop);
        $this->pluginData = $configuration;
    }

    protected function getUserPhone($userId)
    {
        $modelManager = Shopware()->Models();
        $user = $modelManager->find(Customer::class, (int)$userId);

        if ($user) {
            /** @var Address $billingAddress */
            $billingAddress = $user->getDefaultBillingAddress();
            if ($billingAddress) {
                return $billingAddress->getPhone();
            }
        }

        return '';
    }

    protected function getUserBirthday($userId)
    {
        return Shopware()->Models()->getConnection()->createQueryBuilder()
            ->select('birthday')
            ->from('s_user')
            ->where('id = :userId')
            ->setParameter('userId', $userId)
            ->execute()
            ->fetchColumn();
    }

    protected function saveDate($userId, $birthday)
    {
        if (is_array($birthday)) {
            $birthday = $birthday['year'] . '-' . $birthday['month'] . '-' . $birthday['day'];
        }

        Shopware()->Db()->update(
            's_user',
            ['birthday' => $birthday],
            ['id = ?' => $userId]
        );
    }

    protected function savePhone($userId, $phone)
    {
        $modelManager = Shopware()->Models();
        $user = $modelManager->find(Customer::class, (int)$userId);

        if ($user) {
            /** @var Address $billingAddress */
            $billingAddress = $user->getDefaultBillingAddress();
            if ($billingAddress) {
                $billingAddress->setPhone($phone);
                $modelManager->persist($billingAddress);
                $modelManager->persist($user);
                $modelManager->flush();
            }
        }
    }

    /**
     * validates IBAN/BIC fields
     *
     * @param string $ibanbic
     * @return boolean
     */
    protected function isValidIbanBic(string $ibanbic)
    {
        if (!preg_match('/^[A-Z0-9 ]+$/', $ibanbic)) {
            return false;
        } else {
            return true;
        }
    }

    function dumb($data) {
        highlight_string("<?php\n " . var_export($data, true) . "?>");
        echo '<script>document.getElementsByTagName("code")[0].getElementsByTagName("span")[1].remove() ;document.getElementsByTagName("code")[0].getElementsByTagName("span")[document.getElementsByTagName("code")[0].getElementsByTagName("span").length - 1].remove() ; </script>';
        die();
    }
}