<?php
namespace MilleConsorsFinanzRK\Components\PaymentMethods;

use Doctrine\ORM\AbstractQuery;
use MilleConsorsFinanzRK\Bootstrap\Database;

class Invoice extends AbstractPaymentMethod
{
    /**
     * {@inheritdoc}
     */
    public function validate($paymentData)
    {
        $sErrorFlag = [];
        $fields = [
            'ConsorsFinanzInvoicePhone'
        ];

        $fields[1]['ConsorsFinanzInvoiceBirthday'] = [
            'day',
            'month',
            'year'
        ];

        foreach ($fields as $field) {
            $value = $paymentData[$field] ?: '';
            $value = trim($value);

            if (empty($value)) {
                $sErrorFlag[$field] = true;
            }

            if (is_array($field)) {
                foreach ($field as $key => $date) {
                    foreach ($date as $item) {
                        $value = $paymentData[$key][$item] ?: '';
                        $value = trim($value);
                        if (empty($value)) {
                            $sErrorFlag[$field][$item] = true;
                        }
                    }
                }
            }
        }

        if (count($sErrorFlag) > 0) {
            $sErrorMessages[] = Shopware()->Snippets()->getNamespace('frontend/account/internalMessages')
                ->get('ErrorFillIn', 'Please fill in all red fields');

            return [
                'sErrorFlag' => $sErrorFlag,
                'sErrorMessages' => $sErrorMessages,
            ];
        }

        return [];
    }

    /**
     * {@inheritdoc}
     */
    public function savePaymentData($userId, \Enlight_Controller_Request_Request $request)
    {
        if (0 == (int)$userId) {
            return;
        }

        $session = Shopware()->Session();
        $agb = ($request->getParam('ConsorsFinanzInvoiceAgb') === 'true' ? 1 : 0);
        $session->offsetSet('consorsAgbChecked', $agb);

        $this->saveUserBirthday($userId, $request);
        $this->saveUserPhone($userId, $request);

        $paymentMean = Shopware()->Models()->getRepository('\Shopware\Models\Payment\Payment')->
        getActivePaymentsQuery(['name' => Database::DEBIT_PAYMENT_METHOD_NAME])->getOneOrNullResult(AbstractQuery::HYDRATE_ARRAY);

        $data = [
            'iban' => '',
            'bic' => '',
        ];

        $where = [
            'payment_mean_id = ?' => $paymentMean['id'],
            'user_id = ?' => $userId,
        ];

        Shopware()->Db()->update('s_core_payment_data', $data, $where);
    }

    /**
     * {@inheritdoc}
     */
    public function getCurrentPaymentDataAsArray($userId)
    {
        return [
            'ConsorsFinanzInvoiceBirthday' => $this->getUserBirthday($userId),
            'ConsorsFinanzInvoicePhone' => $this->getUserPhone($userId),
        ];
    }

    private function saveUserPhone($userId, \Enlight_Controller_Request_Request $request)
    {
        $phone = $request->getParam('ConsorsFinanzInvoicePhone');
        $this->savePhone($userId, $phone);
    }

    private function saveUserBirthday($userId, \Enlight_Controller_Request_Request $request)
    {
        $birthday = $request->getParam('ConsorsFinanzInvoiceBirthdayHidden');
        if (empty($birthday)) {
            $this->saveDate(
                $userId,
                $request->getParam('ConsorsFinanzInvoiceBirthday')
            );
        }
    }
}