<?php
use MilleConsorsFinanzRK\Components\Consors\Api\ConsorsSoapClientFault;
use MilleConsorsFinanzRK\Components\Consors\Services\OrderService;
use MilleConsorsFinanzRK\Components\DependencyProvider;
use MilleConsorsFinanzRK\Components\Logger\LoggerService;
use MilleConsorsFinanzRK\Components\Configuration;
use MilleConsorsFinanzRK\Components\PaymentStatus;

class ConsorsFinanzBase extends Shopware_Controllers_Frontend_Payment
{
    // Return status codes
    const STATUS_SUCCESS = "success";
    const STATUS_ERROR = "error";

    /**
     * @var LoggerService
     */
    protected $loggerService;

    /**
     * @var DependencyProvider
     */
    protected $dependencyProvider;
    /**
     * @var OrderService
     */
    protected $orderService;

    /**
     * @var Configuration
     */
    protected $configuration;

    /**
     * Pre dispatch method
     */
    public function preDispatch()
    {
        $this->loggerService = $this->container->get('mille_consors_finanz_rk.components.logger.logger_service');
        $this->dependencyProvider = $this->container->get('mille_consors_finanz_rk.components.dependency_provider');
        $this->orderService = $this->container->get('mille_consors_finanz_rk.components.consors.services.order_service');
        $this->configuration = $this->container->get('mille_consors_finanz_rk.components.configuration');
    }

    /**
     * Check if everything is ok and proceed with payment
     *
     * @param $anfrageart
     * @return void
     * @throws ConsorsSoapClientFault
     */
    protected function gateway($anfrageart)
    {
        // Check Basket Quantities before redirect
        $basket = Shopware()->Modules()->Basket();
        $checkQuantities = $basket->sCheckBasketQuantities();
        if (!empty($checkQuantities['hideBasket'])) {
            return $this->redirect(['controller' => 'checkout']);
        }

        $session = $this->dependencyProvider->getSession();

        //create hash
        $orderVariables = $session['sOrderVariables'];
        $orderHash = md5(serialize($orderVariables));
        $session->consorsOrderHash = $orderHash;

        $this->finishOrder($orderHash, $anfrageart);
    }

    /**
     * acutally save order
     *
     * @param $consorsPaymentReference
     * @param $anfrageart
     * @return void to finish page
     * @throws ConsorsSoapClientFault
     */
    public function finishOrder($consorsPaymentReference, $anfrageart)
    {
        $session = $this->dependencyProvider->getSession();

        $orderHash = md5(serialize($session['sOrderVariables']));
        if ($session->consorsOrderHash !== $orderHash) {
            $ordernumber = $this->saveOrder($consorsPaymentReference, $consorsPaymentReference, PaymentStatus::PAYMENT_STATE_REVIEW_NECESSARY);
        } else {
            $ordernumber = $this->saveOrder($consorsPaymentReference, $consorsPaymentReference);
        }

        $order2Response = $this->orderService->order(
            $anfrageart,
            $ordernumber,
            $this->dependencyProvider->getShop()->getId()
        );

        if ($order2Response->getFehlergrund() != 0) {
            $this->saveOrderStatus($consorsPaymentReference, $consorsPaymentReference, \Shopware\Models\Order\Status::ORDER_STATE_CLARIFICATION_REQUIRED);
            $this->orderService->setClearedDate($ordernumber);

            $this->loggerService->error($order2Response->getFehlertext());
            $this->forward('error', 'ConsorsFinanzBase', 'frontend', [
                'errorCode' => $order2Response->getFehlergrund(),
            ]);
        } else {
            $this->loggerService->error(sprintf('Order %s successfully created', $ordernumber));
        }

        if (!empty($session['consorsPaymentReference'])) {
            $session->offsetUnset('consorsPaymentReference');
        }

        $this->removeSessionVariablesOnOrderFinish();

        $this->redirect(array('controller' => 'checkout', 'action' => 'finish', 'sUniqueID' => $consorsPaymentReference));
    }

    public function errorAction()
    {
        $errorCode = $this->Request()->getParam('errorCode');
        $this->redirect([
            'controller' => 'checkout',
            'action' => 'shippingPayment',
            'wConsorsFinanzErrorCode' => $errorCode,
        ]);
    }

    public function saveOrderStatus($transactionId, $paymentUniqueId, $paymentStatusId, $sendStatusMail = false)
    {
        $sql = '
            SELECT id FROM s_order
            WHERE transactionID=? AND temporaryID=?
            AND status!=-1
        ';
        $orderId = (int) Shopware()->Db()->fetchOne($sql, [
            $transactionId,
            $paymentUniqueId,
        ]);
        $order = Shopware()->Modules()->Order();
        $order->setOrderStatus($orderId, $paymentStatusId, $sendStatusMail);
    }

    protected function saveUserBirthday($userID, $birthday = null)
    {
        if (null == $birthday) {
            return;
        }

        $this->container->get('dbal_connection')->update('s_user', ['birthday' => $birthday], ['id' => $userID]);
    }

    /**
     * Removing session variables that have no use anymore
     *
     * @param void
     * @return void
     */
    protected function removeSessionVariablesOnOrderFinish() {
        $session = Shopware()->Session();
        $session->offsetUnset('consorsAgbChecked');
        $session->offsetUnset('consorsPaymentReference');
        $session->offsetUnset('consorsUserReference');
        $session->offsetUnset('consorsOrderHash');
    }
}
