<?php
namespace MilleConsorsFinanzRK;

use Shopware\Components\Plugin;
use Shopware\Components\Plugin\Context\ActivateContext;
use Shopware\Components\Plugin\Context\DeactivateContext;
use Shopware\Components\Plugin\Context\InstallContext;
use Shopware\Components\Plugin\Context\UninstallContext;
use Shopware\Components\Plugin\Context\UpdateContext;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use MilleConsorsFinanzRK\Bootstrap\Attributes;
use MilleConsorsFinanzRK\Bootstrap\Database;
use MilleConsorsFinanzRK\Bootstrap\Installer;
use MilleConsorsFinanzRK\Bootstrap\Updater;

class MilleConsorsFinanzRK extends Plugin
{
    /**
     * @param ContainerBuilder $container
     *
     * @return void
     */
    public function build(ContainerBuilder $container)
    {
        $container->setParameter('mille_consors_finanz_rk.plugin_dir', $this->getPath());
        $container->setParameter('mille_consors_finanz_rk.namespace', $this->getName());
        parent::build($container);
    }

    /**
     * {@inheritdoc}
     */
    public function install(InstallContext $context)
    {
        $this->getInstaller()->install();
    }

    /**
     * {@inheritdoc}
     */
    public function uninstall(UninstallContext $context)
    {
        $installer = $this->getInstaller();
        if (!$context->keepUserData()) {
            $installer->uninstall();
        }
        $context->scheduleMessage('Plugin successfully uninstalled');
        $context->scheduleClearCache(UninstallContext::CACHE_LIST_ALL);
    }

    /**
     * {@inheritdoc}
     */
    public function activate(ActivateContext $context)
    {
        $context->scheduleMessage('Please configure the plugin and compile the theme.');
        parent::activate($context);
    }

    /**
     * {@inheritdoc}
     */
    public function deactivate(DeactivateContext $context)
    {
        $this->getDatabase()->deactivatePaymentMethods();
        parent::deactivate($context);
    }

    /**
     * {@inheritdoc}
     */
    public function update(UpdateContext $context)
    {
        $this->getUpdater()->update($context->getCurrentVersion());
        $context->scheduleClearCache(UpdateContext::CACHE_LIST_ALL);
    }

    /**
     * @return Installer
     */
    public function getInstaller()
    {
        $attribute = new Attributes(
            $this->container->get('shopware_attribute.crud_service'),
            $this->container->get('models')
        );

        $database = new Database(
            $this->container->get('models'),
            $this->getPath()
        );

        return new Installer(
            $attribute,
            $database
        );
    }

    /**
     * @return Database
     */
    public function getDatabase()
    {
        return new Database(
            $this->container->get('models'),
            $this->getPath()
        );
    }

    /**
     * @return Updater
     */
    private function getUpdater()
    {
        $attribute = new Attributes(
            $this->container->get('shopware_attribute.crud_service'),
            $this->container->get('models')
        );

        return new Updater(
            $this->container->get('models'),
            $attribute
        );
    }
}
