<?php
/**
 * Copyright (c) WEB LOUPE. All rights reserved.
 * This file is part of software that is released under a proprietary license.
 * You must not copy, modify, distribute, make publicly available, or execute
 * its contents or parts thereof without express permission by the copyright
 * holder, unless otherwise permitted by law.
 */

namespace WeloConsorsFinanz\Models;

use Shopware\Components\Model\ModelEntity;
use Doctrine\ORM\Mapping as ORM;
use Shopware\Models\Customer\Customer;
use Shopware\Models\Shop\Shop;

/**
 * Class Order
 *
 * @ORM\Entity(repositoryClass="Repository")
 * @ORM\Table(name="s_plugin_welo_consors_finanz_order")
 *
 * @author    WEB LOUPE <shopware@webloupe.de>
 * @copyright Copyright (c) 2017-2020 WEB LOUPE
 * @package   WeloConsorsFinanz\Models
 * @version   1
 */
class Order extends ModelEntity
{
    /**
     * Unique identifier
     *
     * @var int
     *
     * @ORM\Column(name="id", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $id;
    
    /**
     * The id of the selected customer.
     *
     * @var int
     * @ORM\Column(name="customer_id", type="integer", nullable=false)
     */
    private $customerId;
    
    /**
     * @var Customer
     *
     * @ORM\OneToOne(targetEntity="\Shopware\Models\Customer\Customer")
     * @ORM\JoinColumn(name="customer_id", referencedColumnName="id")
     */
    private $customer;
    
    /**
     * @var \Shopware\Models\Order\Order
     *
     * @ORM\OneToOne(targetEntity="Shopware\Models\Order\Order")
     * @ORM\JoinColumn(name="order_id", referencedColumnName="id")
     */
    private $order;
    
    /**
     * The id of the selected order.
     *
     * @var int
     * @ORM\Column(name="order_id", type="integer", nullable=false)
     */
    private $orderId;

    /**
     * @var float
     * @ORM\Column(name="reference_id", type="integer", nullable=false)
     */
    private $referenceId;
    
    /**
     * Datetime of creation
     *
     * @var \DateTime
     * @ORM\Column(name="created", type="datetime")
     */
    private $created;
    
    /**
     * @var Shop
     *
     * @ORM\OneToOne(targetEntity="\Shopware\Models\Shop\Shop")
     * @ORM\JoinColumn(name="shop_id", referencedColumnName="id")
     */
    private $shop;
    
    /**
     * @var int
     * @ORM\Column(name="shop_id", type="integer", nullable=false)
     */
    private $shopId;


    /**
     * @var bool
     * @ORM\Column(name="status", type="integer", nullable=false)
     */
    private $status;

    /**
     * @var string
     * @ORM\Column(name="error_text", type="string", nullable=true)
     */
    private $errorText;

    /**
     * @return \Shopware\Models\Order\Order
     */
    public function getOrder()
    {
        return $this->order;
    }
    
    /**
     * @return int
     */
    public function getId()
    {
        return $this->id;
    }
    
    /**
     * @return Customer
     */
    public function getCustomer()
    {
        return $this->customer;
    }
    
    /**
     * @param int $customerId
     *
     * @return Order
     */
    public function setCustomerId($customerId)
    {
        $this->customerId = $customerId;
        
        return $this;
    }
    
    /**
     * @return int
     */
    public function getCustomerId()
    {
        return $this->customerId;
    }
    
    /**
     * @param int $orderId
     *
     * @return Order
     */
    public function setOrderId($orderId)
    {
        $this->orderId = $orderId;
        
        return $this;
    }
    
    /**
     * @return int
     */
    public function getOrderId()
    {
        return $this->orderId;
    }
    
    /**
     * Set created
     *
     * @param \DateTime|string $created
     *
     * @return Order
     * @throws \Exception
     */
    public function setCreated($created = 'now')
    {
        if (!$created instanceof \DateTime) {
            $created = new \DateTime($created);
        }
        
        $this->created = $created;
        
        return $this;
    }
    
    /**
     * @return \DateTime
     */
    public function getCreated()
    {
        return $this->created;
    }
    
    /**
     * @return integer
     */
    public function getShopId()
    {
        return $this->shopId;
    }
    
    /**
     * @param $shopId
     */
    public function setShopId($shopId)
    {
        $this->shopId = $shopId;
    }
    
    /**
     * @return Shop
     */
    public function getShop()
    {
        return $this->shop;
    }
    
    /**
     * @param $shop
     */
    public function setShop(Shop $shop)
    {
        $this->shop = $shop;
    }

    /**
     * @return integer
     */
    public function getStatus()
    {
        return $this->status;
    }

    /**
     * @param integer $status
     */
    public function setStatus($status)
    {
        $this->status = $status;
    }

    /**
     * @return float
     */
    public function getReferenceId()
    {
        return $this->referenceId;
    }

    /**
     * @param float $referenceId
     */
    public function setReferenceId(float $referenceId)
    {
        $this->referenceId = $referenceId;
    }

    /**
     * @return string
     */
    public function getErrorText()
    {
        return $this->errorText;
    }

    /**
     * @param string $errorText
     */
    public function setErrorText(string $errorText)
    {
        $this->errorText = $errorText;
    }
}
