<?php
namespace MilleConsorsFinanzRK\Subscriber;

use Enlight\Event\SubscriberInterface;
use Enlight_Controller_ActionEventArgs as ActionEventArgs;
use MilleConsorsFinanzRK\Components\Configuration;
use MilleConsorsFinanzRK\Components\DependencyProvider;
use MilleConsorsFinanzRK\Components\Services\ConsorsService;

class Account implements SubscriberInterface
{
    /**
     * @var Configuration
     */
    private $configuration;
    /**
     * @var ConsorsService
     */
    private $consorsService;
    /**
     * @var DependencyProvider
     */
    private $dependencyProvider;

    /**
     * Checkout constructor.
     * @param Configuration      $configuration
     * @param ConsorsService     $consorsService
     * @param DependencyProvider $dependencyProvider
     */
    public function __construct(
        Configuration $configuration,
        ConsorsService $consorsService,
        DependencyProvider $dependencyProvider
    ) {
        $this->configuration = $configuration;
        $this->consorsService = $consorsService;
        $this->dependencyProvider = $dependencyProvider;
    }

    public static function getSubscribedEvents()
    {
        return [
            'Enlight_Controller_Action_PostDispatch_Frontend_Account' => [
                ['onAccountPostDispatch', 1000],
            ],
        ];
    }

    /**
     * @param ActionEventArgs $args
     * @throws \Exception
     */
    public function onAccountPostDispatch(ActionEventArgs $args)
    {
        $request = $args->getRequest();
        $view = $args->getSubject()->View();
        $availableActions = ['payment'];
        $wConsorsFinanz = $this->configuration->getPluginData();

        $sUserData = $view->getAssign('sUserData');
        $paymentId = $sUserData['additional']['payment']['id'];
        $userId = (int)$sUserData['additional']['user']['id'];
        $birthday = $sUserData['additional']['user']['birthday'];
        $phone = $sUserData['billingaddress']['phone'];

        if (!in_array(strtolower($request->getActionName()), $availableActions, true)) {
            return;
        }

        if (!$wConsorsFinanz['isActive']) {
            return;
        }

        $wConsorsFinanz = array_merge(
            $wConsorsFinanz,
            [
                'paymentData' => $this->consorsService->getPaymentData($userId, $paymentId),
                'phone' => $phone,
                'birthday' => $birthday,
                'hasBirthday' => (bool)($birthday != null),
                'consorsAgbChecked' => (bool)$this->dependencyProvider->getSession()->offsetGet('consorsAgbChecked')
            ]
        );

        $view->assign('wConsorsFinanz', $wConsorsFinanz);
    }
}
