<?php
namespace MilleConsorsFinanzRK\Subscriber;

use Enlight\Event\SubscriberInterface;
use Enlight_Controller_ActionEventArgs as ActionEventArgs;
use MilleConsorsFinanzRK\Components\Configuration;
use MilleConsorsFinanzRK\Components\Consors\Api\ConsorsSoapClientFault;
use MilleConsorsFinanzRK\Components\Consors\Services\BoniCheckService;
use MilleConsorsFinanzRK\Components\DependencyProvider;
use MilleConsorsFinanzRK\Components\DependencyProviderInterface;
use MilleConsorsFinanzRK\Components\Logger\LoggerServiceInterface;
use MilleConsorsFinanzRK\Components\Services\ConsorsService;
use MilleConsorsFinanzRK\Components\SettingsTable;
use Shopware\Components\Model\ModelManager;

class Checkout implements SubscriberInterface
{
    /**
     * @var Configuration
     */
    private $configuration;
    /**
     * @var BoniCheckService
     */
    private $boniCheckService;

    /**
     * @var DependencyProviderInterface
     */
    private $dependencyProvider;
    /**
     * @var ConsorsService
     */
    private $consorsService;

    const LEGAL_AGE = 18;
    /**
     * @var LoggerServiceInterface
     */
    private $loggerService;

    /**
     * @var ModelManager
     */
    private $modelManager;

    /**
     * Checkout constructor.
     * @param Configuration          $configuration
     * @param BoniCheckService       $boniCheckService
     * @param DependencyProvider     $dependencyProvider
     * @param ConsorsService         $consorsService
     * @param LoggerServiceInterface $loggerService
     * @param ModelManager           $modelManager
     */
    public function __construct(
        Configuration $configuration,
        BoniCheckService $boniCheckService,
        DependencyProvider $dependencyProvider,
        ConsorsService $consorsService,
        LoggerServiceInterface $loggerService,
        ModelManager $modelManager
    ) {
        $this->configuration = $configuration;
        $this->boniCheckService = $boniCheckService;
        $this->dependencyProvider = $dependencyProvider;
        $this->consorsService = $consorsService;
        $this->loggerService = $loggerService;
        $this->modelManager = $modelManager;
    }

    public static function getSubscribedEvents()
    {
        return [
            'Enlight_Controller_Action_PostDispatchSecure_Frontend_Checkout' => 'onCheckoutPostDispatch',
        ];
    }

    /**
     * @param ActionEventArgs $args
     * @throws \Exception
     */
    public function onCheckoutPostDispatch(ActionEventArgs $args)
    {
        $availableActions = ['shippingpayment', 'confirm'];
        $request = $args->getRequest();
        $wConsorsFinanz = $this->configuration->getPluginData();

        if (!in_array(strtolower($request->getActionName()), $availableActions, true)) {
            return;
        }

        if (!$wConsorsFinanz['isActive']) {
            return;
        }

        switch ($request->getActionName()) {
            case 'confirm': {
                $this->handleConfirm($args, $wConsorsFinanz);
            }
            break;
            case 'shippingPayment': {
                $this->handleShippingPayment($args, $wConsorsFinanz);
            }
            break;
        }
    }

    private function handleShippingPayment($args, $wConsorsFinanz)
    {
        $request = $args->getRequest();
        $view = $args->getSubject()->View();
        $sUserData = $view->getAssign('sUserData');
        $paymentId = $sUserData['additional']['payment']['id'];
        $userId = (int)$sUserData['additional']['user']['id'];
        $birthday = $sUserData['additional']['user']['birthday'];
        $phone = $sUserData['billingaddress']['phone'];
        $wConsorsFinanzPaymentIds = [$wConsorsFinanz['invoicePaymentMethodId'], $wConsorsFinanz['debitPaymentMethodId']];


        if (0 == $userId) {
            $userId = (int)$this->dependencyProvider->getUserId();
        }

        $isIdentical = $this->isIdentical($sUserData['billingaddress'], $sUserData['shippingaddress']);
        $sBasket = $view->getAssign('sBasket');
        $sAmount = $sBasket['sAmount'];

        if (in_array($paymentId, $wConsorsFinanzPaymentIds)) {
            if (!$isIdentical || $sAmount >= $wConsorsFinanz['maxBasketValue']) {
                $sPayments = $view->getAssign('sPayments');

                $arrayPayments = [];
                foreach ($sPayments as $sPayment) {
                    if (!in_array($sPayment['id'], $wConsorsFinanzPaymentIds)) {
                        $arrayPayments[] = $sPayment;
                    }
                }
	            $view->assign('sPayments', $arrayPayments);
            }
        }

        $error = $request->getParam('wConsorsFinanzErrorCode');

        if (isset($error)) {
            $view->assign('wConsorsFinanzErrorCode', $error);
        }

        $wConsorsFinanz = array_merge(
            $wConsorsFinanz,
            [
                'paymentData' => $this->consorsService->getPaymentData($userId, $paymentId),
                'phone' => $phone,
                'birthday' => $birthday,
                'hasBirthday' => (bool)($birthday != null),
                'consorsAgbChecked' => (bool)$this->dependencyProvider->getSession()->offsetGet('consorsAgbChecked')
            ]
        );

        $view->assign('wConsorsFinanz', $wConsorsFinanz);
    }

    /**
     * @param ActionEventArgs $args
     * @param                 $wConsorsFinanz
     * @throws ConsorsSoapClientFault
     * @throws \Exception
     */
    private function handleConfirm(ActionEventArgs $args, $wConsorsFinanz)
    {
        $action = $args->getSubject();
        $view = $args->getSubject()->View();
        $sUserData = $view->getAssign('sUserData');
        $sOrderVariables = $view->getAssign();

        $wConsorsFinanzPaymentIds = [$wConsorsFinanz['invoicePaymentMethodId'], $wConsorsFinanz['debitPaymentMethodId']];
        $paymentId = $sUserData['additional']['payment']['id'];
        $userId = (int)$sUserData['additional']['user']['id'];
        $birthday = $sUserData['additional']['user']['birthday'];

        if (0 == $userId) {
            $userId = (int)$this->dependencyProvider->getUserId();
        }

        $shopId = $this->dependencyProvider->getShop()->getId();

        $isIdentical = $this->isIdentical($sUserData['billingaddress'], $sUserData['shippingaddress']);
        $sBasket = $view->getAssign('sBasket');
        $sAmount = $sBasket['sAmount'];

        if (in_array($paymentId, $wConsorsFinanzPaymentIds)) {
            if (!$isIdentical || $sAmount >= $wConsorsFinanz['maxBasketValue']) {
                return $action->redirect([
                    'controller' => 'checkout',
                    'action' => 'shippingPayment',
                ]);
            }

            $wConsorsFinanz = array_merge(
                $wConsorsFinanz, ['isConsorsPayment' => true]
            );

            if (!$birthday) {
                return $action->redirect([
                    'controller' => 'checkout',
                    'action' => 'shippingPayment',
                    'wConsorsFinanzErrorCode' => 23,
                ]);
            } elseif (!$this->validateBirthDay($birthday)) {
                $this->loggerService->error('Sie müssen mindestens 18 Jahre alt sein, um mit Consors Finanz zu bezahlen');
                return $action->redirect([
                    'controller' => 'checkout',
                    'action' => 'shippingPayment',
                    'wConsorsFinanzErrorCode' => 25,
                ]);
            } else {
                if (!$this->dependencyProvider->getSession()->offsetGet('consorsAgbChecked')) {
                    return $action->redirect([
                        'controller' => 'checkout',
                        'action' => 'shippingPayment'
                    ]);
                }

                if ($paymentId == $wConsorsFinanz['invoicePaymentMethodId']) {
                    $requestType = SettingsTable::REQUEST_TYPE_INVOICE;
                } else {
                    $requestType = SettingsTable::REQUEST_TYPE_DEBIT;
                    $paymentData = $this->consorsService->getPaymentData($userId, $paymentId);

                    if (!$paymentData) {
                        $errorCode = 24;
                        return $action->redirect([
                            'controller' => 'checkout',
                            'action' => 'shippingPayment',
                            'wConsorsFinanzErrorCode' => $errorCode,
                        ]);
                    }
                }

                $boni2CheckResponse = $this->boniCheckService->checkBoni($sOrderVariables, $requestType, $shopId);
                $errorCode = $boni2CheckResponse->getFehlergrund();

                $this->loggerService->error($boni2CheckResponse->getFehlertext());

                if (4 == $errorCode) {
                    $this->dependencyProvider->getSession()->offsetUnset('consorsUserReference');
                    $boni2CheckResponse = $this->boniCheckService->checkBoni($sOrderVariables, $requestType, $shopId);
                    $errorCode = $boni2CheckResponse->getFehlergrund();
                    $this->loggerService->error($boni2CheckResponse->getFehlertext());
                }
            }

            if (0 !== (int)$errorCode) {
                $action->redirect([
                    'controller' => 'checkout',
                    'action' => 'shippingPayment',
                    'wConsorsFinanzErrorCode' => $errorCode,
                ]);
            }
        }
        $view->assign('wConsorsFinanz', $wConsorsFinanz);
    }

    private function validateBirthDay($birthday, $age = self::LEGAL_AGE)
    {
        if (is_string($birthday)) {
            $birthday = strtotime($birthday);
        }

        if (time() - $birthday < $age * 31536000) {
            return false;
        }

        return true;
    }

    public function isIdentical($billing, $shipping)
    {
        $isIdentical = false;

        if (strcmp($shipping['salutation'], $billing['salutation']) == 0
            && strcmp($shipping['firstname'], $billing['firstname']) == 0
            && strcmp($shipping['lastname'], $billing['lastname']) == 0
            && strcmp($shipping['street'], $billing['street']) == 0
            && $shipping['zipcode'] == $billing['zipcode']
            && strcmp($shipping['city'], $billing['city']) == 0
            && $shipping['countryID'] == $billing['countryID']
            && strcmp($shipping['company'], $billing['company']) == 0
            && strcmp($shipping['department'], $billing['department']) == 0
        ) {
            $isIdentical = true;
        }

        return $isIdentical;
    }

    function dumb($data)
    {
        highlight_string("<?php\n " . var_export($data, true) . "?>");
        echo '<script>document.getElementsByTagName("code")[0].getElementsByTagName("span")[1].remove() ;document.getElementsByTagName("code")[0].getElementsByTagName("span")[document.getElementsByTagName("code")[0].getElementsByTagName("span").length - 1].remove() ; </script>';
        die();
    }
}
