<?php
namespace MilleConsorsFinanzRK\Subscriber;

use Enlight\Event\SubscriberInterface;
use Enlight_Template_Manager;
use Shopware\Components\CacheManager;
use Shopware_Controllers_Backend_Config;
use Enlight_Event_EventArgs as EventArgs;

class Template implements SubscriberInterface
{
    /**
     * @var Enlight_Template_Manager
     */
    private $templateManager;
    
    /**
     * @var string
     */
    private $pluginDir;
    /**
     * @var CacheManager
     */
    private $cacheManager;
    private $pluginName;

    /**
     * @param                          $pluginDir
     * @param                          $pluginName
     * @param Enlight_Template_Manager $templateManager
     * @param CacheManager             $cacheManager
     */
    public function __construct(
        $pluginDir,
        $pluginName,
        Enlight_Template_Manager $templateManager,
        CacheManager $cacheManager
    ) {
        $this->templateManager = $templateManager;
        $this->pluginDir = $pluginDir;
        $this->cacheManager = $cacheManager;
        $this->pluginName = $pluginName;
    }
    
    /**
     * {@inheritdoc}
     */
    public static function getSubscribedEvents()
    {
        return [
            'Enlight_Controller_Action_PreDispatch' => ['onPreDispatch', 100],
            'Enlight_Controller_Action_PostDispatchSecure_Backend_Config' => 'onPostDispatchConfig',
            'Theme_Inheritance_Template_Directories_Collected' => ['onTemplateDirectoriesCollect', 1000],
        ];
    }
    
    public function onPreDispatch()
    {
        $this->templateManager->addTemplateDir($this->pluginDir . '/Resources/views');
    }

    public function onPostDispatchConfig(\Enlight_Event_EventArgs $args)
    {
        /** @var Shopware_Controllers_Backend_Config $subject */
        $subject = $args->get('subject');
        $request = $subject->Request();

        // If this is a POST-Request, and affects our plugin, we may clear the config cache
        if($request->isPost() && $request->getParam('name') === $this->pluginName) {
            $this->cacheManager->clearByTag(CacheManager::CACHE_TAG_CONFIG);
        }
    }

    /**
     * @param EventArgs $args
     */
    public function onTemplateDirectoriesCollect(EventArgs $args)
    {
        $dirs = $args->getReturn();
        $dirs[] = $this->pluginDir . '/Resources/views';
        $args->setReturn($dirs);
    }
}
