<?php

/**
 * Shopware 5
 * Copyright (c) shopware AG
 *
 * According to our dual licensing model, this program can be used either
 * under the terms of the GNU Affero General Public License, version 3,
 * or under a proprietary license.
 *
 * The texts of the GNU Affero General Public License with an additional
 * permission and of our proprietary license can be found at and
 * in the LICENSE file you have received along with this program.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * "Shopware" is a registered trademark of shopware AG.
 * The licensing of the program under the AGPLv3 does not imply a
 * trademark license. Therefore any rights, title and interest in
 * our trademarks remain entirely with us.
 */


namespace Shopware\Models\Attribute;
use Shopware\Components\Model\ModelEntity,
    Doctrine\ORM\Mapping AS ORM,
    Symfony\Component\Validator\Constraints as Assert,
    Doctrine\Common\Collections\ArrayCollection;


/**
 * @ORM\Entity
 * @ORM\Table(name="s_order_attributes")
 */
class Order extends ModelEntity
{
    

    /**
     * @var integer $id
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\Column(name="id", type="integer", nullable=false)
     */
     protected $id;


    /**
     * @var integer $orderId
     *
     * @ORM\Column(name="orderID", type="integer", nullable=true)
     */
     protected $orderId;


    /**
     * @var string $attribute1
     *
     * @ORM\Column(name="attribute1", type="text", nullable=true)
     */
     protected $attribute1;


    /**
     * @var string $attribute2
     *
     * @ORM\Column(name="attribute2", type="text", nullable=true)
     */
     protected $attribute2;


    /**
     * @var string $attribute3
     *
     * @ORM\Column(name="attribute3", type="text", nullable=true)
     */
     protected $attribute3;


    /**
     * @var string $attribute4
     *
     * @ORM\Column(name="attribute4", type="text", nullable=true)
     */
     protected $attribute4;


    /**
     * @var string $attribute5
     *
     * @ORM\Column(name="attribute5", type="text", nullable=true)
     */
     protected $attribute5;


    /**
     * @var string $attribute6
     *
     * @ORM\Column(name="attribute6", type="text", nullable=true)
     */
     protected $attribute6;


    /**
     * @var integer $consorsFinanzIsOrderBooked
     *
     * @ORM\Column(name="consors_finanz_is_order_booked", type="integer", nullable=true)
     */
     protected $consorsFinanzIsOrderBooked;


    /**
     * @var integer $consorsFinanzIsOrderCancelled
     *
     * @ORM\Column(name="consors_finanz_is_order_cancelled", type="integer", nullable=true)
     */
     protected $consorsFinanzIsOrderCancelled;


    /**
     * @var string $consorsFinanzOrderCreditNumbers
     *
     * @ORM\Column(name="consors_finanz_order_credit_numbers", type="text", nullable=true)
     */
     protected $consorsFinanzOrderCreditNumbers;


    /**
     * @var string $consorsFinanzOrderInvoiceNumber
     *
     * @ORM\Column(name="consors_finanz_order_invoice_number", type="text", nullable=true)
     */
     protected $consorsFinanzOrderInvoiceNumber;


    /**
     * @var string $consorsFinanzOrderDate
     *
     * @ORM\Column(name="consors_finanz_order_date", type="text", nullable=true)
     */
     protected $consorsFinanzOrderDate;


    /**
     * @var string $consorsFinanzOrderDueDate
     *
     * @ORM\Column(name="consors_finanz_order_due_date", type="text", nullable=true)
     */
     protected $consorsFinanzOrderDueDate;


    /**
     * @var string $consorsFinanzOrderAmount
     *
     * @ORM\Column(name="consors_finanz_order_amount", type="text", nullable=true)
     */
     protected $consorsFinanzOrderAmount;


    /**
     * @var string $consorsFinanzOrderInvoiceType
     *
     * @ORM\Column(name="consors_finanz_order_invoice_type", type="text", nullable=true)
     */
     protected $consorsFinanzOrderInvoiceType;


    /**
     * @var string $consorsFinanzOrderInvoiceReference
     *
     * @ORM\Column(name="consors_finanz_order_invoice_reference", type="text", nullable=true)
     */
     protected $consorsFinanzOrderInvoiceReference;


    /**
     * @var integer $consorsFinanzOrderChangeFlag
     *
     * @ORM\Column(name="consors_finanz_order_change_flag", type="integer", nullable=true)
     */
     protected $consorsFinanzOrderChangeFlag;


    /**
     * @var string $consorsFinanzCustomerNumber
     *
     * @ORM\Column(name="consors_finanz_customer_number", type="text", nullable=true)
     */
     protected $consorsFinanzCustomerNumber;


    /**
     * @var string $swagPaypalUnifiedPaymentType
     *
     * @ORM\Column(name="swag_paypal_unified_payment_type", type="text", nullable=true)
     */
     protected $swagPaypalUnifiedPaymentType;


    /**
     * @var \Shopware\Models\Order\Order
     *
     * @ORM\OneToOne(targetEntity="Shopware\Models\Order\Order", inversedBy="attribute")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="orderID", referencedColumnName="id")
     * })
     */
    protected $order;
    

    public function __construct()
    {
        $this->consorsFinanzIsOrderBooked = 0;
        $this->consorsFinanzIsOrderCancelled = 0;
        $this->consorsFinanzOrderChangeFlag = 0;
    }
    

    public function getId()
    {
        return $this->id;
    }

    public function setId($id)
    {
        $this->id = $id;
        return $this;
    }
    

    public function getOrderId()
    {
        return $this->orderId;
    }

    public function setOrderId($orderId)
    {
        $this->orderId = $orderId;
        return $this;
    }
    

    public function getAttribute1()
    {
        return $this->attribute1;
    }

    public function setAttribute1($attribute1)
    {
        $this->attribute1 = $attribute1;
        return $this;
    }
    

    public function getAttribute2()
    {
        return $this->attribute2;
    }

    public function setAttribute2($attribute2)
    {
        $this->attribute2 = $attribute2;
        return $this;
    }
    

    public function getAttribute3()
    {
        return $this->attribute3;
    }

    public function setAttribute3($attribute3)
    {
        $this->attribute3 = $attribute3;
        return $this;
    }
    

    public function getAttribute4()
    {
        return $this->attribute4;
    }

    public function setAttribute4($attribute4)
    {
        $this->attribute4 = $attribute4;
        return $this;
    }
    

    public function getAttribute5()
    {
        return $this->attribute5;
    }

    public function setAttribute5($attribute5)
    {
        $this->attribute5 = $attribute5;
        return $this;
    }
    

    public function getAttribute6()
    {
        return $this->attribute6;
    }

    public function setAttribute6($attribute6)
    {
        $this->attribute6 = $attribute6;
        return $this;
    }
    

    public function getConsorsFinanzIsOrderBooked()
    {
        return $this->consorsFinanzIsOrderBooked;
    }

    public function setConsorsFinanzIsOrderBooked($consorsFinanzIsOrderBooked)
    {
        $this->consorsFinanzIsOrderBooked = $consorsFinanzIsOrderBooked;
        return $this;
    }
    

    public function getConsorsFinanzIsOrderCancelled()
    {
        return $this->consorsFinanzIsOrderCancelled;
    }

    public function setConsorsFinanzIsOrderCancelled($consorsFinanzIsOrderCancelled)
    {
        $this->consorsFinanzIsOrderCancelled = $consorsFinanzIsOrderCancelled;
        return $this;
    }
    

    public function getConsorsFinanzOrderCreditNumbers()
    {
        return $this->consorsFinanzOrderCreditNumbers;
    }

    public function setConsorsFinanzOrderCreditNumbers($consorsFinanzOrderCreditNumbers)
    {
        $this->consorsFinanzOrderCreditNumbers = $consorsFinanzOrderCreditNumbers;
        return $this;
    }
    

    public function getConsorsFinanzOrderInvoiceNumber()
    {
        return $this->consorsFinanzOrderInvoiceNumber;
    }

    public function setConsorsFinanzOrderInvoiceNumber($consorsFinanzOrderInvoiceNumber)
    {
        $this->consorsFinanzOrderInvoiceNumber = $consorsFinanzOrderInvoiceNumber;
        return $this;
    }
    

    public function getConsorsFinanzOrderDate()
    {
        return $this->consorsFinanzOrderDate;
    }

    public function setConsorsFinanzOrderDate($consorsFinanzOrderDate)
    {
        $this->consorsFinanzOrderDate = $consorsFinanzOrderDate;
        return $this;
    }
    

    public function getConsorsFinanzOrderDueDate()
    {
        return $this->consorsFinanzOrderDueDate;
    }

    public function setConsorsFinanzOrderDueDate($consorsFinanzOrderDueDate)
    {
        $this->consorsFinanzOrderDueDate = $consorsFinanzOrderDueDate;
        return $this;
    }
    

    public function getConsorsFinanzOrderAmount()
    {
        return $this->consorsFinanzOrderAmount;
    }

    public function setConsorsFinanzOrderAmount($consorsFinanzOrderAmount)
    {
        $this->consorsFinanzOrderAmount = $consorsFinanzOrderAmount;
        return $this;
    }
    

    public function getConsorsFinanzOrderInvoiceType()
    {
        return $this->consorsFinanzOrderInvoiceType;
    }

    public function setConsorsFinanzOrderInvoiceType($consorsFinanzOrderInvoiceType)
    {
        $this->consorsFinanzOrderInvoiceType = $consorsFinanzOrderInvoiceType;
        return $this;
    }
    

    public function getConsorsFinanzOrderInvoiceReference()
    {
        return $this->consorsFinanzOrderInvoiceReference;
    }

    public function setConsorsFinanzOrderInvoiceReference($consorsFinanzOrderInvoiceReference)
    {
        $this->consorsFinanzOrderInvoiceReference = $consorsFinanzOrderInvoiceReference;
        return $this;
    }
    

    public function getConsorsFinanzOrderChangeFlag()
    {
        return $this->consorsFinanzOrderChangeFlag;
    }

    public function setConsorsFinanzOrderChangeFlag($consorsFinanzOrderChangeFlag)
    {
        $this->consorsFinanzOrderChangeFlag = $consorsFinanzOrderChangeFlag;
        return $this;
    }
    

    public function getConsorsFinanzCustomerNumber()
    {
        return $this->consorsFinanzCustomerNumber;
    }

    public function setConsorsFinanzCustomerNumber($consorsFinanzCustomerNumber)
    {
        $this->consorsFinanzCustomerNumber = $consorsFinanzCustomerNumber;
        return $this;
    }
    

    public function getSwagPaypalUnifiedPaymentType()
    {
        return $this->swagPaypalUnifiedPaymentType;
    }

    public function setSwagPaypalUnifiedPaymentType($swagPaypalUnifiedPaymentType)
    {
        $this->swagPaypalUnifiedPaymentType = $swagPaypalUnifiedPaymentType;
        return $this;
    }
    

    public function getOrder()
    {
        return $this->order;
    }

    public function setOrder($order)
    {
        $this->order = $order;
        return $this;
    }
    
}